@@ -4,7 +4,7 @@ package gnu.dtools.ritopt;
  * Options.java
  *
  * Version:
- *    $Id: Options.java,v 1.5 2005/07/30 14:48:59 mortenalver Exp $
+ *    $Id: Options.java 2451 2007-10-30 17:28:42Z mortenalver $
 
  */
 
@@ -273,7 +273,7 @@ public class Options implements OptionRegistrar, OptionModuleRegistrar,
     /**
      * Returns the program name displayed in the usage.
      *
-     * @param The program name.
+     * @returns The program name.
      */
 
     public String getUsageProgram() {
@@ -283,7 +283,7 @@ public class Options implements OptionRegistrar, OptionModuleRegistrar,
     /**
      * Returns the version of the program.
      *
-     * @param The version.
+     * @returns The version.
      */
 
     public String getVersion() {
@@ -383,14 +383,6 @@ public class Options implements OptionRegistrar, OptionModuleRegistrar,
         defaultOptionFilename = fn;
     }
 
-    /**
-     * Sets the debugging flag.
-     *
-     * @param flag    The value to set the debugging flag.
-
-    public void setDebugFlag( boolean flag ) {
-        debugFlag = flag;
-    }
 
     /**
      * Displays the program's help which includes a description of each
@@ -587,7 +579,7 @@ public class Options implements OptionRegistrar, OptionModuleRegistrar,
      * Splits a string representing command line arguments into several
      * strings.
      *
-     * @param split   The string to split.
+     * @param str   The string to split.
      *
      * @return  The splitted string.
      */
@@ -694,7 +686,7 @@ public class Options implements OptionRegistrar, OptionModuleRegistrar,
     /**
      * Processes an array of strings representing command line arguments.
      *
-     * @param  The arguments to process.
+     * @param args arguments to process.
      *
      * @return The leftover arguments.
      */
