@@ -36,32 +36,47 @@ Modified for use in JabRef
 
 package net.sf.jabref;
 
-import java.beans.*;
-import java.util.*;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyVetoException;
+import java.beans.VetoableChangeListener;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Hashtable;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.Vector;
 
 import javax.swing.JOptionPane;
 
-import net.sf.jabref.groups.GroupSelector;
+public class BibtexDatabase {
+    
+	Map<String, BibtexEntry> _entries = new Hashtable<String, BibtexEntry>();
 
-public class BibtexDatabase
-{
-    Map _entries = new Hashtable();
-    String _preamble = null;
-    HashMap _strings = new HashMap();
-    Vector _strings_ = new Vector();
-    Hashtable _autoCompleters = null;
-    Set changeListeners = new HashSet();
-    private BibtexDatabase ths = this;
+	String _preamble = null;
 
-    private HashMap allKeys  = new HashMap();	// use a map instead of a set since i need to know how many of each key is inthere
+	HashMap<String, BibtexString> _strings = new HashMap<String, BibtexString>();
 
-    /* Entries are stored in a HashMap with the ID as key.
-     * What happens if someone changes a BibtexEntry's ID
-     * after it has been added to this BibtexDatabase?
-     * The key of that entry would be the old ID, not the new one.
-     * Use a PropertyChangeListener to identify an ID change
-     * and update the Map.
-     */
+	Vector _strings_ = new Vector();
+
+	Set<DatabaseChangeListener> changeListeners = new HashSet<DatabaseChangeListener>();
+
+	/**
+	 * use a map instead of a set since i need to know how many of each key is
+	 * inthere
+	 */
+	private HashMap<String, Integer> allKeys = new HashMap<String, Integer>();
+
+    /*
+	 * Entries are stored in a HashMap with the ID as key. What happens if
+	 * someone changes a BibtexEntry's ID after it has been added to this
+	 * BibtexDatabase? The key of that entry would be the old ID, not the new
+	 * one. Use a PropertyChangeListener to identify an ID change and update the
+	 * Map.
+	 */
     private final VetoableChangeListener listener =
         new VetoableChangeListener()
         {
@@ -69,11 +84,11 @@ public class BibtexDatabase
                 throws PropertyVetoException
             {
                 if (pce.getPropertyName() == null)
-                    fireDatabaseChanged (new DatabaseChangeEvent(ths, DatabaseChangeEvent.CHANGING_ENTRY, (BibtexEntry)pce.getSource()));
+                    fireDatabaseChanged (new DatabaseChangeEvent(BibtexDatabase.this, DatabaseChangeEvent.CHANGING_ENTRY, (BibtexEntry)pce.getSource()));
                 else if ("id".equals(pce.getPropertyName()))
                 {
                     // locate the entry under its old key
-                    Object oldEntry =
+                    BibtexEntry oldEntry =
                         _entries.remove((String) pce.getOldValue());
 
                     if (oldEntry != pce.getSource())
@@ -82,13 +97,13 @@ public class BibtexDatabase
                         // The entry under the old key isn't
                         // the one that sent this event.
                         // Restore the old state.
-                        _entries.put(pce.getOldValue(), oldEntry);
+                        _entries.put((String)pce.getOldValue(), oldEntry);
                         throw new PropertyVetoException("Wrong old ID", pce);
                     }
 
                     if (_entries.get(pce.getNewValue()) != null)
                     {
-                        _entries.put(pce.getOldValue(), oldEntry);
+                        _entries.put((String)pce.getOldValue(), oldEntry);
                         throw new PropertyVetoException
                             ("New ID already in use, please choose another",
                             pce);
@@ -98,7 +113,7 @@ public class BibtexDatabase
                     _entries.put((String) pce.getNewValue(),
                         (BibtexEntry) pce.getSource());
                 } else {
-                    fireDatabaseChanged (new DatabaseChangeEvent(ths, DatabaseChangeEvent.CHANGED_ENTRY, (BibtexEntry)pce.getSource()));
+                    fireDatabaseChanged (new DatabaseChangeEvent(BibtexDatabase.this, DatabaseChangeEvent.CHANGED_ENTRY, (BibtexEntry)pce.getSource()));
                     //Util.pr(pce.getSource().toString()+"\n"+pce.getPropertyName()
                     //    +"\n"+pce.getNewValue());
                 }
@@ -146,7 +161,7 @@ public class BibtexDatabase
         return (BibtexEntry) _entries.get(id);
     }
 
-    public synchronized Collection getEntries() {
+    public synchronized Collection<BibtexEntry> getEntries() {
             return _entries.values();
     }
 
@@ -187,15 +202,15 @@ public class BibtexDatabase
     }
 
     public synchronized BibtexEntry[] getEntriesByKey(String key) {
-        Vector entries = new Vector();
-        BibtexEntry entry;
-        for (Iterator it = _entries.entrySet().iterator(); it.hasNext(); ) {
-            entry = (BibtexEntry)((Map.Entry)it.next()).getValue();
+        
+    	ArrayList<BibtexEntry> entries = new ArrayList<BibtexEntry>();
+        
+        for (BibtexEntry entry : _entries.values()){
             if (key.equals(entry.getCiteKey()))
                 entries.add(entry);
         }
-        BibtexEntry[] entryArray = new BibtexEntry[entries.size()];
-        return (BibtexEntry[]) entries.toArray(entryArray);
+        
+        return entries.toArray(new BibtexEntry[entries.size()]);
     }
 
     /**
@@ -214,16 +229,6 @@ public class BibtexDatabase
 
         entry.addPropertyChangeListener(listener);
 
-        // Possibly add a FieldChangeListener, which is there to add
-        // new words to the autocompleter's dictionary. In case the
-        // entry is non-empty (pasted), update completers.
-        /*if (_autoCompleters != null) {
-            entry.addPropertyChangeListener(new FieldChangeListener
-                                            (_autoCompleters, entry));
-            Util.updateCompletersForEntry(_autoCompleters,
-                                          entry);
-        }
-        */
         _entries.put(id, entry);
 
         fireDatabaseChanged(new DatabaseChangeEvent(this, DatabaseChangeEvent.ADDED_ENTRY, entry));
@@ -334,20 +339,79 @@ public class BibtexDatabase
     }
 
     /**
-     * Resolves any references to strings contained in this database,
+     * Resolves any references to strings contained in this field content,
      * if possible.
      */
     public String resolveForStrings(String content) {
-        return resolveContent(content, new HashSet());
+    	if (content == null){
+    		throw new IllegalArgumentException("Content for resolveForStrings must not be null.");
+    	}
+        return resolveContent(content, new HashSet<String>());
     }
-
+    
     /**
+	 * Take the given collection of BibtexEntry and resolve any string
+	 * references.
+	 * 
+	 * @param entries
+	 *            A collection of BibtexEntries in which all strings of the form
+	 *            #xxx# will be resolved against the hash map of string
+	 *            references stored in the databasee.
+	 *            
+	 * @param inPlace If inPlace is true then the given BibtexEntries will be modified, if false then copies of the BibtexEntries are made before resolving the strings.
+	 * 
+	 * @return a list of bibtexentries, with all strings resolved. It is dependent on the value of inPlace whether copies are made or the given BibtexEntries are modified. 
+	 */
+    public List<BibtexEntry> resolveForStrings(Collection<BibtexEntry> entries, boolean inPlace){
+    	
+    	if (entries == null)
+    		throw new NullPointerException();
+    	
+    	List<BibtexEntry> results = new ArrayList<BibtexEntry>(entries.size());
+    	
+    	for (BibtexEntry entry : entries){
+    		results.add(this.resolveForStrings(entry, inPlace));
+    	}
+    	return results;
+    }
+    
+    /**
+	 * Take the given BibtexEntry and resolve any string references.
+	 * 
+	 * @param entriy
+	 *            A BibtexEntry in which all strings of the form #xxx# will be
+	 *            resolved against the hash map of string references stored in
+	 *            the databasee.
+	 * 
+	 * @param inPlace
+	 *            If inPlace is true then the given BibtexEntry will be
+	 *            modified, if false then a copy is made using close made before
+	 *            resolving the strings.
+	 * 
+	 * @return a BibtexEntry with all string references resolved. It is
+	 *         dependent on the value of inPlace whether a copy is made or the
+	 *         given BibtexEntries is modified.
+	 */
+    public BibtexEntry resolveForStrings(BibtexEntry entry, boolean inPlace) {
+		
+    	if (!inPlace){
+    		entry = (BibtexEntry)entry.clone();
+    	}
+    	
+    	for (Object field : entry.getAllFields()){
+    		entry.setField(field.toString(), this.resolveForStrings(entry.getField(field.toString()).toString()));
+    	}
+    	
+    	return entry;
+	}
+
+	/**
     * If the label represents a string contained in this database, returns
     * that string's content. Resolves references to other strings, taking
     * care not to follow a circular reference pattern.
-    * If the string is undefined, returns the label itself.
+    * If the string is undefined, returns null.
     */
-    private String resolveString(String label, HashSet usedIds) {
+    private String resolveString(String label, HashSet<String> usedIds) {
         for (java.util.Iterator i=_strings.keySet().iterator(); i.hasNext();) {
             BibtexString string = (BibtexString)_strings.get(i.next());
 
@@ -385,10 +449,10 @@ public class BibtexDatabase
             return (String)o;
         }
 
-        return label;
+        return null;
     }
 
-    private String resolveContent(String res, HashSet usedIds) {
+    private String resolveContent(String res, HashSet<String> usedIds) {
         //if (res.matches(".*#[-\\^\\:\\w]+#.*")) {
     if (res.matches(".*#[^#]+#.*")) {
             StringBuffer newRes = new StringBuffer();
@@ -405,10 +469,9 @@ public class BibtexDatabase
                     // now resolve that one.
                     String refLabel = res.substring(next+1, stringEnd);
                     String resolved = resolveString(refLabel, usedIds);
-                    if (refLabel.equals(resolved)) {
-                        // We got just the label in return, so this may not have
-                        // been intended as a string label, or it may be a label for
-                        // an undefined string. Therefore we prefer to display the #
+                    
+                    if (resolved == null) {
+                        // Could not resolve string. Display the #
                         // characters rather than removing them:
                         newRes.append(res.substring(next, stringEnd+1));
                     } else
@@ -498,6 +561,7 @@ public class BibtexDatabase
                         allKeys.put( key, new Integer(1));
                 return exists;
     }
+    
     //========================================================
     // reduce the number of keys by 1. if this number goes to zero then remove from the set
     // note: there is a good reason why we should not use a hashset but use hashmap instead
@@ -529,16 +593,42 @@ public class BibtexDatabase
         changeListeners.remove(l);
     }
 
-    /*
-    public void setCompleters(Hashtable autoCompleters) {
-        _autoCompleters = autoCompleters;
+	/**
+	 * Returns the text stored in the given field of the given bibtex entry
+	 * which belongs to the given database.
+	 * 
+	 * If a database is given, this function will try to resolve any string
+	 * references in the field-value.
+	 * 
+	 * @param field
+	 *            The field to return the value of.
+	 * @param bibtex maybenull
+	 *            The bibtex entry which contains the field.
+	 * @param database maybenull
+	 *            The database of the bibtex entry.
+	 * @return The resolved field value or null if not found.
+	 */
+	public static String getResolvedField(String field, BibtexEntry bibtex,
+			BibtexDatabase database) {
+	
+		if (field.equals("bibtextype"))
+			return bibtex.getType().getName();
+	
+		return getText((String)bibtex.getField(field), database);
+	}
 
-        for (Iterator i=getKeySet().iterator(); i.hasNext();) {
-            BibtexEntry be = getEntryById((String)(i.next()));
-            be.addPropertyChangeListener(new FieldChangeListener
-                                         (autoCompleters, be));
-
-            Util.updateCompletersForEntry(autoCompleters, be);
-        }
-        }*/
+	/**
+	 * Returns a text with references resolved according to an optionally given
+	 * database.
+	
+	 * @param toResolve maybenull The text to resolve.
+	 * @param database maybenull The database to use for resolving the text.
+	 * @return The resolved text or the original text if either the text or the database are null
+	 */
+	public static String getText(String toResolve, BibtexDatabase database) {
+		if (toResolve != null && database != null)
+			return database.resolveForStrings(toResolve);
+		
+		return toResolve;
+	}
 }
