@@ -138,7 +138,21 @@ public class BibtexEntry
                 "Every BibtexEntry must have a type.  Instead of null, use type OTHER");
         }
 
-        _type = type;
+        BibtexEntryType oldType = _type;
+
+        try {
+            // We set the type before throwing the changeEvent, to enable
+            // the change listener to access the new value if the change
+            // sets off a change in database sorting etc.
+            _type = type;
+            firePropertyChangedEvent(GUIGlobals.TYPE_HEADER,
+                    oldType != null ? oldType.getName() : null,
+                    type != null ? type.getName() : null);
+        } catch (PropertyVetoException pve) {
+            pve.printStackTrace();
+        }
+
+
     }
 
     /**
@@ -228,10 +242,6 @@ public class BibtexEntry
                                                "' is reserved");
         }
 
-        // This mechanism is probably not really necessary.
-        //Object normalValue = FieldTypes.normalize(name, value);
-
-
         Object oldValue = _fields.get(name);
 
         try {
@@ -396,7 +406,6 @@ public class BibtexEntry
         return clone;
     }
 
-
     public String toString() {
         return getType().getName()+":"+getField(BibtexFields.KEY_FIELD);
     }
