@@ -108,7 +108,7 @@ public class BibtexFields
     add( new BibtexSingleField( "key", true ) ) ;
     add( new BibtexSingleField( "month", true, GUIGlobals.SMALL_W ) ) ;
     add( new BibtexSingleField( "note", true, GUIGlobals.MEDIUM_W  ) ) ;
-    add( new BibtexSingleField( "number", true, GUIGlobals.SMALL_W, 60  ) ) ;
+    add( new BibtexSingleField( "number", true, GUIGlobals.SMALL_W, 60  ).setNumeric(true) ) ;
     add( new BibtexSingleField( "organization", true, GUIGlobals.MEDIUM_W  ) ) ;
     add( new BibtexSingleField( "pages", true, GUIGlobals.SMALL_W ) ) ;
     add( new BibtexSingleField( "publisher", true, GUIGlobals.MEDIUM_W  ) ) ;
@@ -116,8 +116,8 @@ public class BibtexFields
     add( new BibtexSingleField( "series", true, GUIGlobals.SMALL_W  ) ) ;
     add( new BibtexSingleField( "title", true, 400 ) ) ;
     add( new BibtexSingleField( "type", true, GUIGlobals.SMALL_W  ) ) ;
-    add( new BibtexSingleField( "volume", true, GUIGlobals.SMALL_W, 60  ) ) ;
-    add( new BibtexSingleField( "year", true, GUIGlobals.SMALL_W, 60 ) ) ;
+    add( new BibtexSingleField( "volume", true, GUIGlobals.SMALL_W, 60  ).setNumeric(true) ) ;
+    add( new BibtexSingleField( "year", true, GUIGlobals.SMALL_W, 60 ).setNumeric(true) ) ;
 
     // some semi-standard fields
     dummy = new BibtexSingleField( KEY_FIELD, true ) ;
@@ -133,10 +133,12 @@ public class BibtexFields
     dummy.setPrivate();
     add( dummy ) ;
 
+    add(new BibtexSingleField("pmid", false, GUIGlobals.SMALL_W, 60).setNumeric(true));
 
     // additional fields ------------------------------------------------------
     dummy =  new BibtexSingleField( "citeseercitationcount", false,
                                                  GUIGlobals.SMALL_W, 75) ;
+    dummy.setNumeric(true);
     dummy.setAlternativeDisplayName("Popularity") ;
     add(dummy) ;
     add( new BibtexSingleField( "location", false ) ) ;
@@ -161,6 +163,12 @@ public class BibtexFields
     add( new BibtexSingleField( "keywords", false, GUIGlobals.SMALL_W  ) ) ;
     //FIELD_EXTRAS.put("keywords", "selector");
 
+
+    dummy = new BibtexSingleField(GUIGlobals.FILE_FIELD, false);
+    dummy.setEditorType(GUIGlobals.FILE_LIST_EDITOR);
+    add(dummy);
+
+
     add( new BibtexSingleField( "search", false, 75 ) ) ;
 
 
@@ -172,6 +180,7 @@ public class BibtexFields
     add( dummy ) ;
 
     dummy = new BibtexSingleField( OWNER, false, GUIGlobals.SMALL_W ) ;
+    dummy.setExtras("setOwner");
     dummy.setPrivate();
     add(dummy) ;
 
@@ -283,6 +292,16 @@ public class BibtexFields
     return null ;
   }
 
+
+  public static int getEditorType(String name) {
+    BibtexSingleField sField = getField( name ) ;
+    if (sField != null)
+    {
+      return sField.getEditorType();
+    }
+    return GUIGlobals.STANDARD_EDITOR;      
+  }
+
   public static double getFieldWeight( String name )
   {
     BibtexSingleField sField = getField( name ) ;
@@ -359,6 +378,15 @@ public class BibtexFields
     return false ;
   }
 
+    public static boolean isNumeric( String field ) {
+        BibtexSingleField sField = getField( field ) ;
+        if (sField != null)
+        {
+            return sField.isNumeric() ;
+        }
+        return false ;
+    }
+
   /** returns an string-array with all fieldnames */
   public static Object[] getAllFieldNames()
   {
@@ -408,6 +436,8 @@ public class BibtexFields
     private int length = GUIGlobals.DEFAULT_FIELD_LENGTH ;
     private double weight = GUIGlobals.DEFAULT_FIELD_WEIGHT ;
 
+    private int editorType = GUIGlobals.STANDARD_EDITOR;
+
     // a alternative displayname, e.g. used for
     // "citeseercitationcount"="Popularity"
     private String alternativeDisplayName = null ;
@@ -417,7 +447,11 @@ public class BibtexFields
     // function to this field, for instance a "browse" button for the "pdf" field.
     private String extras = null ;
 
-    // a comma separated list of alternative bibtex-fieldnames, e.g.
+    // This value defines whether contents of this field are expected to be
+    // numeric values. This can be used to sort e.g. volume numbers correctly:
+    private boolean numeric = false;
+
+      // a comma separated list of alternative bibtex-fieldnames, e.g.
     // "LCCN" is the same like "lib-congress"
     // private String otherNames = null ;
 
@@ -510,6 +544,8 @@ public class BibtexFields
     // -----------------------------------------------------------------------
     // -----------------------------------------------------------------------
 
+
+
     private void setFlag( boolean onOff, int flagID)
     {
       if (onOff)  // set the flag
@@ -600,6 +636,14 @@ public class BibtexFields
     {
       return extras ;
     }
+
+    public void setEditorType(int type) {
+        editorType = type;
+    }
+
+    public int getEditorType() {
+        return editorType;
+    }
     // -----------------------------------------------------------------------
 
     public void setWeight( double value )
@@ -625,5 +669,21 @@ public class BibtexFields
       return name ;
     }
 
+
+      /**
+       * Set this field's numeric propery
+       * @param numeric true to indicate that this is a numeric field.
+       * @return this BibtexSingleField instance. Makes it easier to call this
+       *   method on the fly while initializing without using a local variable.
+       */
+      public BibtexSingleField setNumeric(boolean numeric) {
+          this.numeric = numeric;
+          return this;
+      }
+
+      public boolean isNumeric() {
+          return numeric;
+      }
+
   }
 }
