@@ -37,8 +37,8 @@ import javax.swing.JLabel;
 /**
  * FieldEditors is a common interface between the FieldTextField and FieldTextArea.
  * 
- * @author $Author: coezbek $
- * @version $Revision: 1.6 $ ($Date: 2006/09/11 18:47:34 $)
+ * @author $Author: mortenalver $
+ * @version $Revision: 1938 $ ($Date: 2007-02-16 23:03:17 +0100 (Fri, 16 Feb 2007) $)
  *
  */
 public interface FieldEditor {
@@ -80,7 +80,8 @@ public interface FieldEditor {
 
 	public void setEnabled(boolean enabled);
 
-	/**
+    public void updateFont();
+    /**
 	 * paste text into component, it should also take some selected text into
 	 * account
 	 */
