@@ -43,7 +43,7 @@ import javax.swing.JTextArea;
  * multi-line input.
  * 
  * @author $Author: mortenalver $
- * @version $Revision: 1.21 $ ($Date: 2006/09/29 17:31:43 $)
+ * @version $Revision: 2173 $ ($Date: 2007-07-10 11:20:11 +0200 (Tue, 10 Jul 2007) $)
  * 
  */
 public class FieldTextArea extends JTextArea implements FieldEditor {
@@ -65,6 +65,8 @@ public class FieldTextArea extends JTextArea implements FieldEditor {
 	public FieldTextArea(String fieldName_, String content) {
 		super(content);
 
+        updateFont();
+                
 		// Add the global focus listener, so a menu item can see if this field
 		// was focused when an action was called.
 		addFocusListener(Globals.focusListener);
@@ -89,12 +91,12 @@ public class FieldTextArea extends JTextArea implements FieldEditor {
 		return getPreferredSize();
 	}
 
-	public void paint(Graphics g) {
+	/*public void paint(Graphics g) {
 		Graphics2D g2 = (Graphics2D) g;
 		if (antialias)
 			g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
 		super.paint(g2);
-	}
+	}*/
 
 	public String getFieldName() {
 		return fieldName;
@@ -120,7 +122,12 @@ public class FieldTextArea extends JTextArea implements FieldEditor {
 		return this;
 	}
 
-	public void paste(String textToInsert) {
+
+    public void updateFont() {
+        setFont(GUIGlobals.CURRENTFONT);
+    }
+
+    public void paste(String textToInsert) {
 		int sel = getSelectionEnd() - getSelectionStart();
 		if (sel > 0) // selected text available
 			replaceSelection(textToInsert);
