@@ -177,12 +177,12 @@ public class HelpContent extends JTextPane {
 		return pane;
 	}
 
-	public void paintComponent(Graphics g) {
+	/*public void paintComponent(Graphics g) {
 		Graphics2D g2 = (Graphics2D) g;
 		g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
 		g2.setRenderingHint(RenderingHints.KEY_RENDERING, RenderingHints.VALUE_RENDER_QUALITY);
 		super.paintComponent(g2);
-	}
+	}*/
 
 	public class MyNextVisualPositionAction extends TextAction {
 		private Action textActn;
