@@ -65,7 +65,7 @@ public class JabRef {
     boolean graphicFailure = false;
 
     StringOption importFile, exportFile, exportPrefs, importPrefs, auxImExport, importToOpenBase;
-    BooleanOption helpO, disableGui, blank, loadSess, showVersion;
+    BooleanOption helpO, disableGui, blank, loadSess, showVersion, disableSplash;
     /*
     * class StringArrayOption extends ArrayOption { public public void
     * modify(String value) { } public void modify(String[] value) { } public
@@ -80,7 +80,8 @@ public class JabRef {
     public JabRef(String[] args) {
 
         ths = this;
-
+	// Activate antialiasing on Java 5:
+	System.getProperties().put( "swing.aatext", "true" );
         // The following two lines signal that the system proxy settings should be used:
         System.setProperty("java.net.useSystemProxies", "true");
         System.getProperties().put( "proxySet", "true" );
@@ -148,6 +149,7 @@ public class JabRef {
         exportFile = new StringOption("");
         helpO = new BooleanOption();
         disableGui = new BooleanOption();
+        disableSplash = new BooleanOption();
         blank = new BooleanOption();
         loadSess = new BooleanOption();
         showVersion = new BooleanOption();
@@ -164,6 +166,8 @@ public class JabRef {
                 Globals.lang("Display version"), showVersion);
         options.register("nogui", 'n',
             Globals.lang("No GUI. Only process command line options."), disableGui);
+        options.register("nosplash", 's',
+                Globals.lang("Do not show splash window at startup"), disableSplash);
         options.register("import", 'i',
             Globals.lang("Import file") + ": " + Globals.lang("filename")
             + "[,import format]", importFile);
@@ -219,7 +223,7 @@ public class JabRef {
         // that the GUI
         // should not be opened. This is used to decide whether we should show the
         // splash screen or not.
-        if (initialStartup && !disableGui.isInvoked()) {
+        if (initialStartup && !disableGui.isInvoked() && !disableSplash.isInvoked()) {
             try {
 
                 splashScreen = SplashScreen.splash();
@@ -368,6 +372,13 @@ public class JabRef {
                     // This signals that the latest import should be stored in the given
                     // format to the given file.
                     ParserResult pr = (ParserResult) loaded.elementAt(loaded.size() - 1);
+
+                    // Set the global variable for this database's file directory before exporting,
+                    // so formatters can resolve linked files correctly.
+                    // (This is an ugly hack!)
+                    MetaData metaData = new MetaData(pr.getMetaData(), pr.getDatabase());
+                    metaData.setFile(pr.getFile());
+                    Globals.prefs.fileDirForDatabase = metaData.getFileDirectory(GUIGlobals.FILE_FIELD);
                     System.out.println(Globals.lang("Exporting") + ": " + data[0]);
                     ExportFormat format = ExportFormats.getExportFormat(data[1]);
                     if (format != null) {
@@ -506,9 +517,13 @@ public class JabRef {
             // Jabref version.
             Util.performCompatibilityUpdate();
 
+
             // Set up custom or default icon theme:
             GUIGlobals.setUpIconTheme();
 
+            // TODO: remove temporary registering of external file types?
+            Globals.prefs.updateExternalFileTypes();
+
            // This property is set to make the Mac OSX Java VM move the menu bar to
             // the top
             // of the screen, where Mac users expect it to be.
@@ -688,8 +703,9 @@ lastEdLoop:
             if (loaded.size() > 0) {
                 for (Iterator i=loaded.iterator(); i.hasNext();) {
                     ParserResult pr = (ParserResult)i.next();
-		    jrf.addTab(pr.getDatabase(), pr.getFile(), pr.getMetaData(), pr.getEncoding(), first);
-		    first = false;
+		            BasePanel panel = jrf.addTab(pr.getDatabase(), pr.getFile(),
+                            pr.getMetaData(), pr.getEncoding(), first);
+                    first = false;
                 }
             }
 
@@ -702,6 +718,10 @@ lastEdLoop:
                 splashScreen = null;
             }
 
+            /*JOptionPane.showMessageDialog(null, Globals.lang("Please note that this "
+                +"is an early beta version. Do not use it without backing up your files!"),
+                    Globals.lang("Beta version"), JOptionPane.WARNING_MESSAGE);*/
+
             //Util.pr(": Showing frame");
             jrf.setVisible(true);
 
@@ -724,6 +744,17 @@ lastEdLoop:
                 }
             }
 
+            // After adding the databases, go through each and see if
+            // any post open actions need to be done. For instance, checking
+            // if we found new entry types that can be imported, or checking
+            // if the database contents should be modified due to new features
+            // in this version of JabRef:
+            for (int i = 0; i < loaded.size(); i++) {
+                ParserResult pr = (ParserResult) loaded.elementAt(i);
+                BasePanel panel = jrf.baseAt(i);
+                OpenDatabaseAction.performPostOpenActions(panel, pr, true);
+            }
+
             //Util.pr(": Finished adding panels");
 
             if (loaded.size() > 0) {
