@@ -37,9 +37,11 @@ import net.sf.jabref.imports.CustomImportList;
 import java.awt.*;
 import java.util.prefs.*;
 import java.util.*;
+import java.util.List;
 import java.awt.event.*;
 import net.sf.jabref.export.ExportComparator;
 import net.sf.jabref.external.ExternalFileType;
+import net.sf.jabref.external.UnknownExternalFileType;
 
 public class JabRefPreferences {
 
@@ -50,6 +52,10 @@ public class JabRefPreferences {
         CUSTOM_TAB_NAME = "customTabName_",
         CUSTOM_TAB_FIELDS = "customTabFields_";
 
+    // This String is used in the encoded list in prefs of external file type
+    // modifications, in order to indicate a removed default file type:
+    public static final String FILE_TYPE_REMOVED_FLAG = "REMOVED";
+
     public String WRAPPED_USERNAME;
 
     Preferences prefs;
@@ -64,14 +70,21 @@ public class JabRefPreferences {
     // Object containing custom export formats:
     public CustomExportList customExports;
 
-    /** Set with all custom {@link ImportFormat}s */
+    /** Set with all custom {@link net.sf.jabref.imports.ImportFormat}s */
     public CustomImportList customImports;
 
     // Object containing info about customized entry editor tabs.
     private EntryEditorTabList tabList = null;
 
     // Map containing all registered external file types:
-    private Map externalFileTypes = new HashMap();
+    private TreeSet externalFileTypes = new TreeSet();
+
+    // The following field is used as a global variable during the export of a database.
+    // By setting this field to the path of the database's default file directory, formatters
+    // that should resolve external file paths can access this field. This is an ugly hack
+    // to solve the problem of formatters not having access to any context except for the
+    // string to be formatted and possible formatter arguments.
+    public String fileDirForDatabase = null;
 
     // The only instance of this class:
     private static JabRefPreferences singleton = null;
@@ -97,14 +110,18 @@ public class JabRefPreferences {
 			defaults.put("psviewer", "cmd.exe /c start /b");
 			defaults.put("htmlviewer", "cmd.exe /c start /b");
 			defaults.put("lookAndFeel", "com.jgoodies.plaf.windows.ExtWindowsLookAndFeel");
-		} else {
-			defaults.put("pdfviewer", "acroread");
+            defaults.put("winEdtPath", "C:\\Program Files\\WinEdt Team\\WinEdt\\WinEdt.exe");
+            defaults.put("latexEditorPath", "C:\\Program Files\\LEd\\LEd.exe");
+        } else {
+			defaults.put("pdfviewer", "evince");
 			defaults.put("psviewer", "gv");
 			defaults.put("htmlviewer", "mozilla");
 			defaults.put("lookAndFeel", "com.jgoodies.plaf.plastic.Plastic3DLookAndFeel");
 		}
         defaults.put("useDefaultLookAndFeel", Boolean.TRUE);
         defaults.put("lyxpipe", System.getProperty("user.home")+File.separator+".lyx/lyxpipe");
+        defaults.put("vim", "vim");
+        defaults.put("vimServer", "vim");
         defaults.put("posX", new Integer(0));
         defaults.put("posY", new Integer(0));
         defaults.put("sizeX", new Integer(840));
@@ -134,7 +151,8 @@ public class JabRefPreferences {
         defaults.put("numberColWidth",new Integer(GUIGlobals.NUMBER_COL_LENGTH));
         defaults.put("workingDirectory", System.getProperty("user.home"));
         defaults.put("exportWorkingDirectory", System.getProperty("user.home"));
-        defaults.put("importWorkingDirectory", System.getProperty("user.home"));        
+        defaults.put("importWorkingDirectory", System.getProperty("user.home"));
+        defaults.put("fileWorkingDirectory", System.getProperty("user.home"));
         defaults.put("autoOpenForm", Boolean.TRUE);
         defaults.put("entryTypeFormHeightFactor", new Integer(1));
         defaults.put("entryTypeFormWidth", new Integer(1));
@@ -162,7 +180,7 @@ public class JabRefPreferences {
         defaults.put("searchPanePosX", new Integer(0));
         defaults.put("searchPanePosY", new Integer(0));
         defaults.put("autoComplete", Boolean.TRUE);
-        defaults.put("autoCompFields", new byte[] {0, 1, 28});
+        defaults.put("autoCompleteFields", "author;editor;title;journal;publisher;keywords");
         defaults.put("groupSelectorVisible", Boolean.TRUE);
         defaults.put("groupFloatSelections", Boolean.TRUE);
         defaults.put("groupIntersectSelections", Boolean.TRUE);
@@ -180,13 +198,11 @@ public class JabRefPreferences {
         defaults.put("highlightGroupsMatchingAll", Boolean.FALSE);
         defaults.put("searchPanelVisible", Boolean.FALSE);
         defaults.put("defaultEncoding", System.getProperty("file.encoding"));
-        defaults.put("winEdtPath", "C:\\Program Files\\WinEdt Team\\WinEdt\\WinEdt.exe");
-        defaults.put("latexEditorPath", "C:\\TEMP\\Led.exe");
         defaults.put("groupsVisibleRows", new Integer(8));
         defaults.put("defaultOwner", System.getProperty("user.name"));
         defaults.put("preserveFieldFormatting", Boolean.FALSE);
     // The general fields stuff is made obsolete by the CUSTOM_TAB_... entries.
-        defaults.put("generalFields", "crossref;keywords;doi;url;urldate;citeseerurl;"+
+        defaults.put("generalFields", "crossref;keywords;file;doi;url;urldate;citeseerurl;"+
                      "pdf;comment;owner");
 
         defaults.put("useCustomIconTheme", Boolean.FALSE);
@@ -194,8 +210,8 @@ public class JabRefPreferences {
 
     // Entry editor tab 0:
     defaults.put(CUSTOM_TAB_NAME+"_def0", Globals.lang("General"));
-        defaults.put(CUSTOM_TAB_FIELDS+"_def0", "crossref;keywords;doi;url;citeseerurl;"+
-                     "pdf;comment;owner;timestamp");
+        defaults.put(CUSTOM_TAB_FIELDS+"_def0", "crossref;keywords;file;doi;url;citeseerurl;"+
+                     "comment;owner;timestamp");
 
     // Entry editor tab 1:
         defaults.put(CUSTOM_TAB_FIELDS+"_def1", "abstract");
@@ -230,10 +246,12 @@ public class JabRefPreferences {
         defaults.put("antialias", Boolean.FALSE);
         defaults.put("ctrlClick", Boolean.FALSE);
         defaults.put("disableOnMultipleSelection", Boolean.FALSE);
-        defaults.put("pdfColumn", Boolean.TRUE);
+        defaults.put("pdfColumn", Boolean.FALSE);
         defaults.put("urlColumn", Boolean.TRUE);
+        defaults.put("fileColumn", Boolean.TRUE);
         defaults.put("citeseerColumn", Boolean.FALSE);
         defaults.put("useOwner", Boolean.TRUE);
+        defaults.put("overwriteOwner", Boolean.FALSE);
         defaults.put("allowTableEditing", Boolean.FALSE);
         defaults.put("dialogWarningForDuplicateKey", Boolean.TRUE);
         defaults.put("dialogWarningForEmptyKey", Boolean.TRUE);
@@ -247,8 +265,8 @@ public class JabRefPreferences {
         defaults.put("preview0", "<font face=\"arial\">"
                      +"<b><i>\\bibtextype</i><a name=\"\\bibtexkey\">\\begin{bibtexkey} (\\bibtexkey)</a>"
                      +"\\end{bibtexkey}</b><br>__NEWLINE__"
-                     +"\\begin{author} \\format[AuthorLastFirst,HTMLChars,AuthorAbbreviator,AuthorAndsReplacer]{\\author}<BR>\\end{author}__NEWLINE__"
-                     +"\\begin{editor} \\format[AuthorLastFirst,HTMLChars,AuthorAbbreviator,AuthorAndsReplacer]{\\editor} <i>(ed.)</i><BR>\\end{editor}__NEWLINE__"
+                     +"\\begin{author} \\format[HTMLChars,AuthorAbbreviator,AuthorAndsReplacer]{\\author}<BR>\\end{author}__NEWLINE__"
+                     +"\\begin{editor} \\format[HTMLChars,AuthorAbbreviator,AuthorAndsReplacer]{\\editor} <i>(ed.)</i><BR>\\end{editor}__NEWLINE__"
                      +"\\begin{title} \\format[HTMLChars]{\\title} \\end{title}<BR>__NEWLINE__"
                      +"\\begin{chapter} \\format[HTMLChars]{\\chapter}<BR>\\end{chapter}__NEWLINE__"
                      +"\\begin{journal} <em>\\format[HTMLChars]{\\journal}, </em>\\end{journal}__NEWLINE__"
@@ -264,8 +282,8 @@ public class JabRefPreferences {
         defaults.put("preview1", "<font face=\"arial\">"
                      +"<b><i>\\bibtextype</i><a name=\"\\bibtexkey\">\\begin{bibtexkey} (\\bibtexkey)</a>"
                      +"\\end{bibtexkey}</b><br>__NEWLINE__"
-                     +"\\begin{author} \\format[AuthorLastFirst,HTMLChars,AuthorAbbreviator,AuthorAndsReplacer]{\\author}<BR>\\end{author}__NEWLINE__"
-                     +"\\begin{editor} \\format[AuthorLastFirst,HTMLChars,AuthorAbbreviator,AuthorAndsReplacer]{\\editor} <i>(ed.)</i><BR>\\end{editor}__NEWLINE__"
+                     +"\\begin{author} \\format[HTMLChars,AuthorAbbreviator,AuthorAndsReplacer]{\\author}<BR>\\end{author}__NEWLINE__"
+                     +"\\begin{editor} \\format[HTMLChars,AuthorAbbreviator,AuthorAndsReplacer]{\\editor} <i>(ed.)</i><BR>\\end{editor}__NEWLINE__"
                      +"\\begin{title} \\format[HTMLChars]{\\title} \\end{title}<BR>__NEWLINE__"
                      +"\\begin{chapter} \\format[HTMLChars]{\\chapter}<BR>\\end{chapter}__NEWLINE__"
                      +"\\begin{journal} <em>\\format[HTMLChars]{\\journal}, </em>\\end{journal}__NEWLINE__"
@@ -280,6 +298,8 @@ public class JabRefPreferences {
                      +"\\begin{review}<BR><BR><b>Review: </b> \\format[HTMLChars]{\\review} \\end{review}"
                      +"</dd>__NEWLINE__<p></p></font>");
         defaults.put("autoDoubleBraces", Boolean.FALSE);
+        defaults.put("doNotResolveStringsFor", "url");
+        defaults.put("resolveStringsAllFields", Boolean.FALSE);
         defaults.put("putBracesAroundCapitals","");//"title;journal;booktitle;review;abstract");
         defaults.put("nonWrappableFields", "pdf;ps;url;doi");
         defaults.put("useImportInspectionDialog", Boolean.TRUE);
@@ -287,6 +307,7 @@ public class JabRefPreferences {
         defaults.put("generateKeysAfterInspection", Boolean.TRUE);
         defaults.put("warnAboutDuplicatesInInspection", Boolean.TRUE);
         defaults.put("useTimeStamp", Boolean.TRUE);
+        defaults.put("overwriteTimeStamp", Boolean.FALSE);
         defaults.put("timeStampFormat", "yyyy.MM.dd");
 //        defaults.put("timeStampField", "timestamp");
         defaults.put("timeStampField", BibtexFields.TIMESTAMP);
@@ -300,10 +321,21 @@ public class JabRefPreferences {
         defaults.put("citeCommand", "cite");
         defaults.put("floatMarkedEntries", Boolean.TRUE);
 
-        defaults.put("useNativeFileDialogOnMac", Boolean.TRUE);
+        defaults.put("useNativeFileDialogOnMac", Boolean.FALSE);
 
         defaults.put("lastUsedExport", null);
         defaults.put("sidePaneWidth", new Integer(-1));
+
+        defaults.put("importInspectionDialogWidth", new Integer(650));
+        defaults.put("importInspectionDialogHeight", new Integer(650));
+
+        defaults.put("showFileLinksUpgradeWarning", Boolean.TRUE);
+
+        defaults.put("autolinkExactKeyOnly", Boolean.TRUE);
+        //defaults.put("lastAutodetectedImport", "");
+
+        //defaults.put("autoRemoveExactDuplicates", Boolean.FALSE);
+        //defaults.put("confirmAutoRemoveExactDuplicates", Boolean.TRUE);
         
         //defaults.put("tempDir", System.getProperty("java.io.tmpdir"));
         //Util.pr(System.getProperty("java.io.tempdir"));
@@ -319,9 +351,6 @@ public class JabRefPreferences {
         updateSpecialFieldHandling();
         WRAPPED_USERNAME = "["+get("defaultOwner")+"]";
 
-        // TODO: remove temporary registering of external file types?
-        updateExternalFileTypes();
-        
         String defaultExpression = "**/.*[bibtexkey].*\\\\.[extension]";
         defaults.put(DEFAULT_REG_EXP_SEARCH_EXPRESSION_KEY, defaultExpression);
         defaults.put(REG_EXP_SEARCH_EXPRESSION_KEY, defaultExpression);
@@ -492,7 +521,7 @@ public class JabRefPreferences {
 
     /**
      * Looks up a color definition in preferences, and returns an array containing the RGB values.
-     * @param key The key for this setting.
+     * @param value The key for this setting.
      * @return The RGB values corresponding to this color setting.
      */
     public int[] getRgb(String value) {
@@ -676,6 +705,7 @@ public class JabRefPreferences {
         defKeyBinds.put("Open database", "ctrl O");
         defKeyBinds.put("Save database", "ctrl S");
         defKeyBinds.put("Save database as ...", "ctrl shift S");
+        defKeyBinds.put("Save all", "ctrl alt S");
         defKeyBinds.put("Close database", "ctrl W");
         defKeyBinds.put("New entry", "ctrl N");
         defKeyBinds.put("Cut", "ctrl X");
@@ -724,7 +754,8 @@ public class JabRefPreferences {
         defKeyBinds.put("Previous tab", "ctrl PAGE_UP");
         defKeyBinds.put("Replace string", "ctrl R");
         defKeyBinds.put("Delete", "DELETE");
-        defKeyBinds.put("Open PDF or PS", "F4");
+        defKeyBinds.put("Open file", "F4");
+        defKeyBinds.put("Open PDF or PS", "shift F5");
         defKeyBinds.put("Open URL or DOI", "F3");
         defKeyBinds.put("Toggle entry preview", "ctrl F9");
         defKeyBinds.put("Switch preview layout", "F9");
@@ -736,14 +767,16 @@ public class JabRefPreferences {
         defKeyBinds.put("New from plain text", "ctrl shift N");
         defKeyBinds.put("Import Fields from CiteSeer", "ctrl shift C");
         defKeyBinds.put("Fetch citations from CiteSeer", "F7");
+        defKeyBinds.put("Synchronize files", "ctrl F4");
         defKeyBinds.put("Synchronize PDF", "shift F4");
-        defKeyBinds.put("Synchronize PS", "ctrl F4");
+        defKeyBinds.put("Synchronize PS", "ctrl shift F4");
+
         defKeyBinds.put("Abbreviate", "ctrl alt A");
         defKeyBinds.put("Unabbreviate", "ctrl alt shift A");
-        defKeyBinds.put("Search IEEXplore", "F8");
+        defKeyBinds.put("Search IEEEXplore", "F8");
         defKeyBinds.put("Fetch ArXiv.org", "shift F8");
         defKeyBinds.put("Write XMP", "ctrl F4");
-
+        defKeyBinds.put("New file link", "ctrl N");
         //defKeyBinds.put("Select value", "ctrl B");
     }
 
@@ -820,14 +853,60 @@ public class JabRefPreferences {
 
     }
 
+
+
+    public List<ExternalFileType> getDefaultExternalFileTypes() {
+        List<ExternalFileType> list = new ArrayList<ExternalFileType>();
+        list.add(new ExternalFileType("PDF", "pdf", "evince", "pdfSmall"));
+        list.add(new ExternalFileType("PostScript", "ps", "evince", "psSmall"));
+        list.add(new ExternalFileType("Word", "doc", "oowriter", "openoffice"));
+        list.add(new ExternalFileType("OpenDocument text", "odt", "oowriter", "openoffice"));
+        list.add(new ExternalFileType("Excel", "xls", "oocalc", "openoffice"));
+        list.add(new ExternalFileType("OpenDocument spreadsheet", "ods", "oocalc", "openoffice"));
+        list.add(new ExternalFileType("PowerPoint", "ppt", "ooimpress", "openoffice"));
+        list.add(new ExternalFileType("OpenDocument presentation", "odp", "ooimpress", "openoffice"));
+        list.add(new ExternalFileType("Rich Text Format", "rtf", "oowriter", "openoffice"));
+        list.add(new ExternalFileType("PNG image", "png", "gimp", "picture"));
+        list.add(new ExternalFileType("GIF image", "gif", "gimp", "picture"));
+        list.add(new ExternalFileType("JPG image", "jpg", "gimp", "picture"));
+        list.add(new ExternalFileType("Djvu", "djvu", "evince", "psSmall"));
+        list.add(new ExternalFileType("Text", "txt", "emacs", "emacs"));
+        list.add(new ExternalFileType("LaTeX", "tex", "emacs", "emacs"));
+        list.add(new ExternalFileType("CHM", "chm", "gnochm", "www"));
+        list.add(new ExternalFileType("TIFF image", "tiff", "gimp", "picture"));
+        ExternalFileType tp = new ExternalFileType("URL", "html", "firefox", "www");
+        list.add(tp);
+
+        // Under Windows/Mac we initialize all file types with an empty viewer app, to
+        // rely on the default app instead:
+        if (Globals.ON_WIN || Globals.ON_MAC) {
+            for (Iterator<ExternalFileType> iterator = list.iterator(); iterator.hasNext();) {
+                ExternalFileType type = iterator.next();
+                type.setOpenWith("");
+            }
+        }
+
+        return list;
+    }
+
+    public ExternalFileType[] getExternalFileTypeSelection() {
+        return (ExternalFileType[])externalFileTypes.toArray
+                (new ExternalFileType[externalFileTypes.size()]);
+    }
+
     /**
-     *
+     * Look up the external file type registered with this name, if any.
+     * @param name The file type name.
+     * @return The ExternalFileType registered, or null if none.
      */
-    public void updateExternalFileTypes() {
-        externalFileTypes.put("pdf", new ExternalFileType("PDF", "pdf", get("pdfviewer"), null));
-        externalFileTypes.put("ps", new ExternalFileType("PostScript", "ps", get("psviewer"), null));
-        externalFileTypes.put("doc", new ExternalFileType("Word file", "doc", "oowriter", null));
-        externalFileTypes.put("odt", new ExternalFileType("OpenDocument text", "odt", "oowriter", null));
+    public ExternalFileType getExternalFileTypeByName(String name) {
+        for (Iterator iterator = externalFileTypes.iterator(); iterator.hasNext();) {
+            ExternalFileType type = (ExternalFileType) iterator.next();
+            if (type.getName().equals(name))
+                return type;
+        }
+        // Return an instance that signifies an unknown file type:
+        return new UnknownExternalFileType(name);
     }
 
     /**
@@ -835,8 +914,132 @@ public class JabRefPreferences {
      * @param extension The file extension.
      * @return The ExternalFileType registered, or null if none.
      */
-    public ExternalFileType getExternalFileType(String extension) {
-        return (ExternalFileType)externalFileTypes.get(extension);
+    public ExternalFileType getExternalFileTypeByExt(String extension) {
+        for (Iterator iterator = externalFileTypes.iterator(); iterator.hasNext();) {
+            ExternalFileType type = (ExternalFileType) iterator.next();
+            if (type.getExtension().equals(extension))
+                return type;
+        }
+        return null;
+    }
+
+
+    /**
+     * Reset the List of external file types after user customization.
+     * @param types The new List of external file types. This is the complete list, not
+     *  just new entries.
+     */
+    public void setExternalFileTypes(List<ExternalFileType> types) {
+
+        // First find a list of the default types:
+        List<ExternalFileType> defTypes = getDefaultExternalFileTypes();
+        // Make a list of types that are unchanged:
+        List<ExternalFileType> unchanged = new ArrayList<ExternalFileType>();
+
+        externalFileTypes.clear();
+        for (Iterator<ExternalFileType> iterator = types.iterator(); iterator.hasNext();) {
+            ExternalFileType type = iterator.next();
+            externalFileTypes.add(type);
+
+            // See if we can find a type with matching name in the default type list:
+            ExternalFileType found = null;
+            for (ExternalFileType defType : defTypes) {
+                if (defType.getName().equals(type.getName())) {
+                    found = defType;
+                    break;
+                }
+            }
+            if (found != null) {
+                // Found it! Check if it is an exact match, or if it has been customized:
+                if (found.equals(type))
+                    unchanged.add(type);
+                else {
+                    // It was modified. Remove its entry from the defaults list, since
+                    // the type hasn't been removed:
+                    defTypes.remove(found);
+                }
+            }
+        }
+
+        // Go through unchanged types. Remove them from the ones that should be stored,
+        // and from the list of defaults, since we don't need to mention these in prefs:
+        for (ExternalFileType type : unchanged) {
+            defTypes.remove(type);
+            types.remove(type);
+        }
+
+        // Now set up the array to write to prefs, containing all new types, all modified
+        // types, and a flag denoting each default type that has been removed:
+        String[][] array = new String[types.size()+defTypes.size()][];
+        int i=0;
+        for (ExternalFileType type : types) {
+            array[i] = type.getStringArrayRepresentation();
+            i++;
+        }
+        for (ExternalFileType type : defTypes) {
+            array[i] = new String[] {type.getName(), FILE_TYPE_REMOVED_FLAG};
+            i++;
+        }
+        //System.out.println("Encoded: '"+Util.encodeStringArray(array)+"'");
+        put("externalFileTypes", Util.encodeStringArray(array));
+    }
+
+    
+    /**
+     * Set up the list of external file types, either from default values, or from values
+     * recorded in Preferences.
+     */
+    public void updateExternalFileTypes() {
+        // First get a list of the default file types as a starting point:
+        List<ExternalFileType> types = getDefaultExternalFileTypes();
+        // If no changes have been stored, simply use the defaults:
+        if (prefs.get("externalFileTypes", null) == null) {
+            externalFileTypes.clear();
+            externalFileTypes.addAll(types);
+            return;
+        }
+        // Read the prefs information for file types:
+        String[][] vals = Util.decodeStringDoubleArray(prefs.get("externalFileTypes", ""));
+        for (int i = 0; i < vals.length; i++) {
+            if ((vals[i].length == 2) && (vals[i][1].equals(FILE_TYPE_REMOVED_FLAG))) {
+                // This entry indicates that a default entry type should be removed:
+                ExternalFileType toRemove = null;
+                for (ExternalFileType type : types) {
+                    if (type.getName().equals(vals[i][0])) {
+                        toRemove = type;
+                        break;
+                    }
+                }
+                // If we found it, remove it from the type list:
+                if (toRemove != null)
+                    types.remove(toRemove);
+            }
+            else {
+                // A new or modified entry type. Construct it from the string array:
+                ExternalFileType type = new ExternalFileType(vals[i]);
+                // Check if there is a default type with the same name. If so, this is a
+                // modification of that type, so remove the default one:
+                ExternalFileType toRemove = null;
+                for (ExternalFileType defType : types) {
+                    if (type.getName().equals(defType.getName())) {
+                        toRemove = defType;
+                        break;
+                    }
+                }
+                // If we found it, remove it from the type list:
+                if (toRemove != null) {
+                    types.remove(toRemove);
+                }
+                
+                // Then add the new one:
+                types.add(type);
+            }
+        }
+
+        // Finally, build the list of types based on the modified defaults list:
+        for (ExternalFileType type : types) {
+            externalFileTypes.add(type);
+        }
     }
 
 
