@@ -81,25 +81,29 @@ public class PrefsDialog3 extends JDialog {
 		// ----------------------------------------------------------------
 		ArrayList tabs = new ArrayList();
 		tabs.add(new GeneralTab(frame, prefs));
-		tabs.add(new GroupsPrefsTab(prefs));
+        tabs.add(new FileTab(frame, prefs));
+        tabs.add(new EntryEditorPrefsTab(frame, prefs));
+        tabs.add(new GroupsPrefsTab(prefs));
 		tabs.add(new AppearancePrefsTab(prefs));
-		tabs.add(new ExternalTab(frame, prefs, parent.helpDiag));
+		tabs.add(new ExternalTab(frame, this, prefs, parent.helpDiag));
 		tabs.add(new TablePrefsTab(prefs, parent));
 		tabs.add(new TableColumnsTab(prefs, parent));
 		tabs.add(new TabLabelPattern(prefs, parent.helpDiag));
 		tabs.add(new PreviewPrefsTab(prefs));
 		tabs.add(new NameFormatterTab(parent.helpDiag));
 		tabs.add(new XmpPrefsTab());
-                tabs.add(new AdvancedTab(prefs, parent.helpDiag));
+        tabs.add(new AdvancedTab(prefs, parent.helpDiag));
 		
 		Iterator it = tabs.iterator();
 		String[] names = new String[tabs.size()];
 		int i = 0;
-		while (it.hasNext()) {
+        //ArrayList<Component> comps = new ArrayList<Component>();
+        while (it.hasNext()) {
 			PrefsTab tab = (PrefsTab) it.next();
 			names[i++] = tab.getTabName(); 
 			main.add((Component) tab, tab.getTabName());
-		}
+            //comps.add((Component)tab); // for debug only
+        }
 
 		upper.setBorder(BorderFactory.createEtchedBorder());
 
@@ -192,7 +196,8 @@ public class PrefsDialog3 extends JDialog {
 					setValues();
 					BibtexEntryType.loadCustomEntryTypes(prefs);
 					frame.removeCachedEntryEditors();
-				} catch (IOException ex) {
+                    Globals.prefs.updateEntryEditorTabList();
+                } catch (IOException ex) {
 					JOptionPane.showMessageDialog(PrefsDialog3.this, Globals
 						.lang("Could not import preferences")
 						+ ": " + ex.getMessage(), Globals.lang("Import preferences"),
@@ -206,7 +211,13 @@ public class PrefsDialog3 extends JDialog {
 		setValues();
 
 		pack(); // setSize(440, 500);
-	}
+
+        /** Look through component sizes to find which tab is to blame
+         *  when the dialog grows too large:
+        for (Component co : comps) {
+            System.out.println(co.getPreferredSize());
+        }*/
+    }
 
 	class OkAction extends AbstractAction {
 		public OkAction() {
