@@ -24,8 +24,8 @@ import net.sf.jabref.export.layout.LayoutHelper;
 /**
  * Displays an BibtexEntry using the given layout format.
  * 
- * @author $Author: coezbek $
- * @version $Revision: 1.15 $ ($Date: 2006/09/03 19:09:59 $)
+ * @author $Author: mortenalver $
+ * @version $Revision: 2173 $ ($Date: 2007-07-10 11:20:11 +0200 (Tue, 10 Jul 2007) $)
  *
  */
 public class PreviewPanel extends JEditorPane implements VetoableChangeListener {
@@ -158,14 +158,14 @@ public class PreviewPanel extends JEditorPane implements VetoableChangeListener
 		return getPreferredSize();
 	}
 
-	public void paintComponent(Graphics g) {
+	/*public void paintComponent(Graphics g) {
 		Graphics2D g2 = (Graphics2D) g;
 		Object hint = g2.getRenderingHint(RenderingHints.KEY_ANTIALIASING);
 		g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
 		g2.setRenderingHint(RenderingHints.KEY_RENDERING, RenderingHints.VALUE_RENDER_QUALITY);
 		super.paintComponent(g2);
 		g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, hint);
-	}
+	}*/
 
     /**
      * The PreviewPanel has registered itself as an event listener with the currently displayed
