@@ -35,25 +35,10 @@
 //               (now we cannot change the dateformat dynamicly, sorry)
 package net.sf.jabref;
 
-import java.awt.BorderLayout;
-import java.awt.CardLayout;
-import java.awt.Color;
-import java.awt.Component;
-import java.awt.Dimension;
-import java.awt.Font;
-import java.awt.Point;
+import java.awt.*;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.io.BufferedInputStream;
-import java.io.BufferedOutputStream;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
-import java.io.FilenameFilter;
-import java.io.IOException;
-import java.io.PrintWriter;
-import java.io.StringWriter;
-import java.io.UnsupportedEncodingException;
+import java.io.*;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URLDecoder;
@@ -61,38 +46,25 @@ import java.nio.charset.Charset;
 import java.nio.charset.CharsetEncoder;
 import java.text.NumberFormat;
 import java.text.SimpleDateFormat;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Calendar;
-import java.util.Collection;
-import java.util.Date;
-import java.util.GregorianCalendar;
-import java.util.HashSet;
-import java.util.Iterator;
-import java.util.LinkedList;
+import java.util.*;
 import java.util.List;
-import java.util.SortedSet;
-import java.util.StringTokenizer;
-import java.util.TreeSet;
-import java.util.Vector;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import javax.swing.Box;
-import javax.swing.JButton;
-import javax.swing.JFrame;
-import javax.swing.JLabel;
-import javax.swing.JOptionPane;
-import javax.swing.JPanel;
-import javax.swing.JScrollPane;
-import javax.swing.JTextArea;
+import javax.swing.*;
 import javax.swing.undo.UndoableEdit;
 
 import net.sf.jabref.export.layout.LayoutEntry;
 import net.sf.jabref.export.layout.LayoutFormatter;
 import net.sf.jabref.external.ExternalFileType;
+import net.sf.jabref.external.ExternalFileTypeEntryEditor;
+import net.sf.jabref.external.UnknownExternalFileType;
 import net.sf.jabref.groups.AbstractGroup;
 import net.sf.jabref.groups.KeywordGroup;
+import net.sf.jabref.gui.AutoCompleter;
+import net.sf.jabref.gui.FileListEntry;
+import net.sf.jabref.gui.FileListEntryEditor;
+import net.sf.jabref.gui.FileListTableModel;
 import net.sf.jabref.imports.CiteSeerFetcher;
 import net.sf.jabref.undo.NamedCompound;
 import net.sf.jabref.undo.UndoableFieldChange;
@@ -490,7 +462,7 @@ public class Util {
 
 		if (fieldName.equals("ps") || fieldName.equals("pdf")) {
 
-			// Find the default directory for this field type:
+            // Find the default directory for this field type:
 			String dir = metaData.getFileDirectory(fieldName);
 
 			File file = expandFilename(link, new String[] { dir, "." });
@@ -511,7 +483,11 @@ public class Util {
 					|| (split.length >= 3 && split[split.length - 2].equalsIgnoreCase("ps")))
 					fieldName = "ps";
 			}
-		} else if (fieldName.equals("doi")) {
+
+            // Find the file type descriptor:
+            ExternalFileType type = Globals.prefs.getExternalFileTypeByExt(fieldName);
+
+        } else if (fieldName.equals("doi")) {
 			fieldName = "url";
 			// Check to see if link field already contains a well formated URL
 			if (!link.startsWith("http://")) {
@@ -560,7 +536,9 @@ public class Util {
 		} else if (fieldName.equals("ps")) {
 			try {
 				if (Globals.ON_MAC) {
-					String[] cmd = { "/usr/bin/open", "-a", Globals.prefs.get("psviewer"), link };
+                    ExternalFileType type = Globals.prefs.getExternalFileTypeByExt("ps");
+                    String viewer = type != null ? type.getOpenWith() : Globals.prefs.get("psviewer");
+                    String[] cmd = { "/usr/bin/open", "-a", viewer, link };
 					Process child = Runtime.getRuntime().exec(cmd);
 				} else if (Globals.ON_WIN) {
 					openFileOnWindows(link, true);
@@ -570,7 +548,9 @@ public class Util {
 					 * cmdArray[0] + " " + cmdArray[1]);
 					 */
 				} else {
-					cmdArray[0] = Globals.prefs.get("psviewer");
+                    ExternalFileType type = Globals.prefs.getExternalFileTypeByExt("ps");
+                    String viewer = type != null ? type.getOpenWith() : Globals.prefs.get("psviewer");
+                    cmdArray[0] = viewer;
 					cmdArray[1] = link;
 					Process child = Runtime.getRuntime().exec(cmdArray);
 				}
@@ -581,7 +561,9 @@ public class Util {
 		} else if (fieldName.equals("pdf")) {
 			try {
 				if (Globals.ON_MAC) {
-					String[] cmd = { "/usr/bin/open", "-a", Globals.prefs.get("pdfviewer"), link };
+                    ExternalFileType type = Globals.prefs.getExternalFileTypeByExt("pdf");
+                    String viewer = type != null ? type.getOpenWith() : Globals.prefs.get("psviewer");
+                    String[] cmd = { "/usr/bin/open", "-a", viewer, link };
 					Process child = Runtime.getRuntime().exec(cmd);
 				} else if (Globals.ON_WIN) {
 					openFileOnWindows(link, true);
@@ -597,7 +579,9 @@ public class Util {
 					 * Process child = Runtime.getRuntime().exec(cmd);
 					 */
 				} else {
-					cmdArray[0] = Globals.prefs.get("pdfviewer");
+                    ExternalFileType type = Globals.prefs.getExternalFileTypeByExt("pdf");
+                    String viewer = type != null ? type.getOpenWith() : Globals.prefs.get("psviewer");
+                    cmdArray[0] = viewer;
 					cmdArray[1] = link;
 					// Process child = Runtime.getRuntime().exec(cmdArray[0]+"
 					// "+cmdArray[1]);
@@ -642,10 +626,26 @@ public class Util {
 		} else {
 			cmd = "cmd.exe /c start " + link;
 		}
-		Process child = Runtime.getRuntime().exec(cmd);
+
+        Runtime.getRuntime().exec(cmd);
 	}
 
-	/**
+    /**
+     * Opens a file on a Windows system, using the given application.
+     *
+     * @param link The file name.
+     * @param application Link to the app that opens the file.
+     * @throws IOException
+     */
+    public static void openFileWithApplicationOnWindows(String link, String application)
+        throws IOException {
+
+        link = link.replaceAll("&", "\"&\"").replaceAll(" ", "\" \"");
+
+		Runtime.getRuntime().exec(application + " " + link);
+    }
+
+    /**
 	 * Open an external file, attempting to use the correct viewer for it.
 	 * 
 	 * @param metaData
@@ -653,14 +653,18 @@ public class Util {
 	 * @param link
 	 *            The file name.
 	 */
-	public static void openExternalFileAnyFormat(MetaData metaData, String link) throws IOException {
+	public static void openExternalFileAnyFormat(MetaData metaData, String link,
+                                                 ExternalFileType fileType) throws IOException {
 
-		// For other platforms we'll try to find the file type:
+
+        boolean httpLink = link.toLowerCase().startsWith("http");
+
+        // For other platforms we'll try to find the file type:
 		File file = new File(link);
 
 		// We try to check the extension for the file:
 		String name = file.getName();
-		int pos = name.indexOf('.');
+		int pos = name.lastIndexOf('.');
 		String extension = ((pos >= 0) && (pos < name.length() - 1)) ? name.substring(pos + 1)
 			.trim().toLowerCase() : null;
 
@@ -670,35 +674,53 @@ public class Util {
 		 * extension. Could not find viewer for file.")); }
 		 */
 
-		// Now we know the extension, check if it is one we know about:
-		ExternalFileType fileType = Globals.prefs.getExternalFileType(extension);
-
 		// Find the default directory for this field type, if any:
 		String dir = metaData.getFileDirectory(extension);
-		if (dir != null) {
-			File tmp = expandFilename(link, new String[] { dir, "." });
-			if (tmp != null)
-				file = tmp;
-		}
+        // Include the standard "file" directory:
+        String fileDir = metaData.getFileDirectory(GUIGlobals.FILE_FIELD);
 
-		// Check if we have arrived at an existing file:
-		if (file.exists() && (fileType != null)) {
+        // Include the directory of the bib file:
+        String[] dirs;
+        if (metaData.getFile() != null) {
+            String databaseDir = metaData.getFile().getParent();
+            dirs = new String[] { dir, fileDir, databaseDir };
+        }
+        else
+            dirs = new String[] { dir, fileDir };
+
+        if (!httpLink) {
+            File tmp = expandFilename(link, dirs);
+            if (tmp != null)
+                file = tmp;
+        }
+
+        // Check if we have arrived at a file type, and either an http link or an existing file:
+		if ((httpLink || file.exists()) && (fileType != null)) {
 			// Open the file:
 			try {
-				if (Globals.ON_MAC) {
-					String[] cmd = { "/usr/bin/open", "-a", fileType.getOpenWith(), file.getPath() };
-					Runtime.getRuntime().exec(cmd);
-				} else if (Globals.ON_WIN) {
-					openFileOnWindows(file.getPath(), true);
+                String filePath = httpLink ? link : file.getPath();
+                if (Globals.ON_MAC) {
+		    // Use "-a <application>" if the app is specified, and just "open <filename>" otherwise:
+                    String[] cmd = ((fileType.getOpenWith() != null) && (fileType.getOpenWith().length() > 0)) ?
+                            new String[] { "/usr/bin/open", "-a", fileType.getOpenWith(), filePath } :
+                            new String[] { "/usr/bin/open", filePath };
+		    Runtime.getRuntime().exec(cmd);		
+		} else if (Globals.ON_WIN) {
+                    if ((fileType.getOpenWith() != null) && (fileType.getOpenWith().length() > 0)) {
+                        // Application is specified. Use it:
+                        openFileWithApplicationOnWindows(filePath, fileType.getOpenWith());
+                    } else
+                        openFileOnWindows(filePath, true);
 				} else {
-					String[] cmdArray = new String[] { fileType.getOpenWith(), file.getPath() };
+                    String[] cmdArray = new String[] { fileType.getOpenWith(), filePath };
 					Runtime.getRuntime().exec(cmdArray);
 				}
 			} catch (IOException e) {
-				e.printStackTrace();
+                throw e;
+                /*e.printStackTrace();
 				System.err.println("An error occured on the command: " + fileType.getOpenWith()
 					+ " #" + link);
-				System.err.println(e.getMessage());
+				System.err.println(e.getMessage());*/
 			}
 
 		} else {
@@ -728,7 +750,84 @@ public class Util {
 		}
 	}
 
-	/**
+public static void openExternalFileUnknown(JabRefFrame frame, BibtexEntry entry, MetaData metaData,
+                                           String link, UnknownExternalFileType fileType) throws IOException {
+
+    String cancelMessage = Globals.lang("Unable to open file.");
+    String[] options = new String[] {Globals.lang("Define '%0'", fileType.getName()),
+            Globals.lang("Change file type"), Globals.lang("Cancel")};
+    String defOption = options[0];
+    int answer = JOptionPane.showOptionDialog(frame, Globals.lang("This external link is of the type '%0', which is undefined. What do you want to do?",
+            fileType.getName()),
+            Globals.lang("Undefined file type"), JOptionPane.YES_NO_CANCEL_OPTION,
+            JOptionPane.QUESTION_MESSAGE, null, options, defOption);
+    if (answer == JOptionPane.CANCEL_OPTION) {
+        frame.output(cancelMessage);
+        return;
+    }
+    else if (answer == JOptionPane.YES_OPTION) {
+        // User wants to define the new file type. Show the dialog:
+        ExternalFileType newType = new ExternalFileType(fileType.getName(), "", "", "new");
+        ExternalFileTypeEntryEditor editor = new ExternalFileTypeEntryEditor(frame, newType);
+        editor.setVisible(true);
+        if (editor.okPressed()) {
+            // Get the old list of types, add this one, and update the list in prefs:
+            List<ExternalFileType> fileTypes = new ArrayList<ExternalFileType>();
+            ExternalFileType[] oldTypes = Globals.prefs.getExternalFileTypeSelection();
+            for (int i = 0; i < oldTypes.length; i++) {
+                fileTypes.add(oldTypes[i]);
+            }
+            fileTypes.add(newType);
+            Collections.sort(fileTypes);
+            Globals.prefs.setExternalFileTypes(fileTypes);
+            // Finally, open the file:
+            openExternalFileAnyFormat(metaData, link, newType);
+        } else {
+            // Cancelled:
+            frame.output(cancelMessage);
+            return;
+        }
+    }
+    else {
+        // User wants to change the type of this link.
+        // First get a model of all file links for this entry:
+        FileListTableModel tModel = new FileListTableModel();
+        String oldValue = (String)entry.getField(GUIGlobals.FILE_FIELD);
+        tModel.setContent(oldValue);
+        FileListEntry flEntry = null;
+        // Then find which one we are looking at:
+        for (int i=0; i<tModel.getRowCount(); i++) {
+            FileListEntry iEntry = tModel.getEntry(i);
+            if (iEntry.getLink().equals(link)) {
+                flEntry = iEntry;
+                break;
+            }
+        }
+        if (flEntry == null) {
+            // This shouldn't happen, so I'm not sure what to put in here:
+            throw new RuntimeException("Could not find the file list entry "+link+" in "+entry.toString());
+        }
+
+        FileListEntryEditor editor = new FileListEntryEditor(frame, flEntry, false, true, metaData);
+        editor.setVisible(true);
+        if (editor.okPressed()) {
+            // Store the changes and add an undo edit:
+            String newValue = tModel.getStringRepresentation();
+            UndoableFieldChange ce = new UndoableFieldChange(entry, GUIGlobals.FILE_FIELD,
+                    oldValue, newValue);
+            entry.setField(GUIGlobals.FILE_FIELD, newValue);
+            frame.basePanel().undoManager.addEdit(ce);
+            frame.basePanel().markBaseChanged();
+            // Finally, open the link:
+            openExternalFileAnyFormat(metaData, flEntry.getLink(), flEntry.getType());
+        } else {
+            // Cancelled:
+            frame.output(cancelMessage);
+            return;
+        }
+    }
+}
+    /**
 	 * Make sure an URL is "portable", in that it doesn't contain bad characters
 	 * that break the open command in some OSes.
 	 * 
@@ -784,6 +883,104 @@ public class Util {
 			return null;
 	}
 
+	public static Map<BibtexEntry, List<File>> findAssociatedFiles(Collection<BibtexEntry> entries, Collection<String> extensions, Collection<File> directories){
+		HashMap<BibtexEntry, List<File>> result = new HashMap<BibtexEntry, List<File>>();
+	
+		// First scan directories
+		Set<File> filesWithExtension = findFiles(extensions, directories);
+		
+		// Initialize Result-Set
+		for (BibtexEntry entry : entries){
+			result.put(entry, new ArrayList<File>());
+		}
+
+        boolean exactOnly = Globals.prefs.getBoolean("autolinkExactKeyOnly");
+        // Now look for keys
+		nextFile:
+		for (File file : filesWithExtension){
+			
+			String name = file.getName();
+            int dot = name.lastIndexOf('.');
+            // First, look for exact matches:
+            for (BibtexEntry entry : entries){
+                String citeKey = entry.getCiteKey();
+                if ((citeKey != null) && (citeKey.length() > 0)) {
+                    if (dot > 0) {
+                        if (name.substring(0, dot).equals(citeKey)) {
+                            result.get(entry).add(file);
+                            continue nextFile;
+                        }
+                    }
+                }
+            }
+            // If we get here, we didn't find any exact matches. If non-exact
+            // matches are allowed, try to find one:
+            if (!exactOnly) {
+                for (BibtexEntry entry : entries){
+                    String citeKey = entry.getCiteKey();
+                    if ((citeKey != null) && (citeKey.length() > 0)) {
+                        if (name.startsWith(citeKey)){
+                            result.get(entry).add(file);
+                            continue nextFile;
+                        }
+                    }
+                }
+            }
+		}
+		
+		return result;
+	}
+	
+	public static Set<File> findFiles(Collection<String> extensions, Collection<File> directories) {
+		Set<File> result = new HashSet<File>();
+		
+		for (File directory : directories){
+			result.addAll(findFiles(extensions, directory));
+		}
+		
+		return result;
+	}
+
+	private static Collection<? extends File> findFiles(Collection<String> extensions, File directory) {
+		Set<File> result = new HashSet<File>();
+		
+		File[] children = directory.listFiles();
+		if (children == null)
+			return result; // No permission?
+
+		for (File child : children){
+			if (child.isDirectory()) {
+				result.addAll(findFiles(extensions, child));
+			} else {
+				
+				String extension = getFileExtension(child);
+					
+				if (extension != null){
+					if (extensions.contains(extension)){
+						result.add(child);
+					}
+				}
+			}
+		}
+		
+		return result;
+	}
+
+	/**
+	 * Returns the extension of a file or null if the file does not have one (no . in name).
+	 * 
+	 * @param file
+	 * 
+	 * @return The extension, trimmed and in lowercase.
+	 */
+	public static String getFileExtension(File file) {
+		String name = file.getName();
+		int pos = name.lastIndexOf('.');
+		String extension = ((pos >= 0) && (pos < name.length() - 1)) ? name.substring(pos + 1)
+			.trim().toLowerCase() : null;
+		return extension;
+	}
+
 	/**
 	 * New version of findPdf that uses findFiles.
 	 * 
@@ -814,20 +1011,37 @@ public class Util {
 		return findFile(entry, null, directories, regularExpression, true);
 	}
 
-	/**
+    /**
+     * Convenience menthod for findPDF. Searches for a file of the given type.
+     * @param entry The BibtexEntry to search for a link for.
+     * @param fileType The file type to search for.
+     * @return The link to the file found, or null if not found.
+     */
+    public static String findFile(BibtexEntry entry, ExternalFileType fileType, List extraDirs) {
+
+        List dirs = new ArrayList();
+        dirs.addAll(extraDirs);
+        if (Globals.prefs.hasKey(fileType.getExtension()+"Directory")) {
+            dirs.add(Globals.prefs.get(fileType.getExtension()+"Directory"));
+        }
+        String [] directories = (String[])dirs.toArray(new String[dirs.size()]);
+        return findPdf(entry, fileType.getExtension(), directories);
+    }
+
+    /**
 	 * Searches the given directory and file name pattern for a file for the
 	 * bibtexentry.
-	 * 
+	 *
 	 * Used to fix:
-	 * 
+	 *
 	 * http://sourceforge.net/tracker/index.php?func=detail&aid=1503410&group_id=92314&atid=600309
-	 * 
+	 *
 	 * Requirements:
 	 *  - Be able to find the associated PDF in a set of given directories.
 	 *  - Be able to return a relative path or absolute path.
 	 *  - Be fast.
 	 *  - Allow for flexible naming schemes in the PDFs.
-	 * 
+	 *
 	 * Syntax scheme for file:
 	 * <ul>
 	 * <li>* Any subDir</li>
@@ -835,7 +1049,7 @@ public class Util {
 	 * <li>[key] Key from bibtex file and database</li>
 	 * <li>.* Anything else is taken to be a Regular expression.</li>
 	 * </ul>
-	 * 
+	 *
 	 * @param entry
 	 *            non-null
 	 * @param database
@@ -847,10 +1061,10 @@ public class Util {
 	 *            the file attribute for this.
 	 * @param file
 	 *            non-null
-	 * 
+	 *
 	 * @param relative
 	 *            whether to return relative file paths or absolute ones
-	 * 
+	 *
 	 * @return Will return the first file found to match the given criteria or
 	 *         null if none was found.
 	 */
@@ -858,7 +1072,6 @@ public class Util {
 		String file, boolean relative) {
 
 		for (int i = 0; i < directory.length; i++) {
-
 			String result = findFile(entry, database, directory[i], file, relative);
 			if (result != null) {
 				return result;
@@ -869,7 +1082,7 @@ public class Util {
 
 	/**
 	 * Removes optional square brackets from the string s
-	 * 
+	 *
 	 * @param s
 	 * @return
 	 */
@@ -879,9 +1092,9 @@ public class Util {
 		return s.substring(beginIndex, endIndex);
 	}
 
-	public static ArrayList parseMethodsCalls(String calls) throws RuntimeException {
+	public static ArrayList<String[]> parseMethodsCalls(String calls) throws RuntimeException {
 
-		ArrayList result = new ArrayList();
+		ArrayList<String[]> result = new ArrayList<String[]>();
 
 		char[] c = calls.toCharArray();
 
@@ -899,19 +1112,50 @@ public class Util {
 
 					String method = calls.substring(start, i);
 
+					// Skip the brace
 					i++;
-					i++;
+					if (i < c.length){
+						if (c[i] == '"'){
+							// Parameter is in format "xxx"
 
-					int startParam = i;
-					i++;
+							// Skip "
+							i++;
 
-					while (i + 1 < c.length && !(c[i] == '"' && c[i + 1] == ')')) {
-						i++;
+							int startParam = i;
+							i++;
+		                    boolean escaped = false;
+							while (i + 1 < c.length &&
+                                    !(!escaped && c[i] == '"' && c[i + 1] == ')')) {
+                                if (c[i] == '\\') {
+                                    escaped = !escaped;
+                                }
+                                else
+                                    escaped = false;
+                                i++;
+
+                            }
+
+							String param = calls.substring(startParam, i);
+                            result.add(new String[] { method, param });
+						} else {
+							// Parameter is in format xxx
+
+							int startParam = i;
+
+							while (i < c.length && c[i] != ')') {
+								i++;
+							}
+
+							String param = calls.substring(startParam, i);
+
+							result.add(new String[] { method, param });
+
+
+						}
+					} else {
+						// Incorrecly terminated open brace
+						result.add(new String[] { method });
 					}
-
-					String param = calls.substring(startParam, i);
-
-					result.add(new String[] { method, param });
 				} else {
 					String method = calls.substring(start, i);
 					result.add(new String[] { method });
@@ -927,7 +1171,7 @@ public class Util {
 	 * Accepts a string like [author:toLowerCase("escapedstring"),toUpperCase],
 	 * whereas the first string signifies the bibtex-field to get while the
 	 * others are the names of layouters that will be applied.
-	 * 
+	 *
 	 * @param fieldAndFormat
 	 * @param entry
 	 * @param database
@@ -954,7 +1198,7 @@ public class Util {
 			return null;
 		}
 
-		String fieldValue = getField(beforeColon, entry, database);
+		String fieldValue = BibtexDatabase.getResolvedField(beforeColon, entry, database);
 
 		if (fieldValue == null)
 			return null;
@@ -974,22 +1218,9 @@ public class Util {
 		return fieldValue;
 	}
 
-	public static String getField(String field, BibtexEntry bibtex, BibtexDatabase database) {
-
-		if (field.equals("bibtextype"))
-			return bibtex.getType().getName();
-
-		String res = (String) bibtex.getField(field);
-
-		if ((res != null) && (database != null))
-			res = database.resolveForStrings(res);
-
-		return res;
-	}
-
 	/**
 	 * Convenience function for absolute search.
-	 * 
+	 *
 	 * Uses findFile(BibtexEntry, BibtexDatabase, (String)null, String, false).
 	 */
 	public static String findFile(BibtexEntry entry, BibtexDatabase database, String file) {
@@ -999,7 +1230,7 @@ public class Util {
 	/**
 	 * Internal Version of findFile, which also accepts a current directory to
 	 * base the search on.
-	 * 
+	 *
 	 */
 	public static String findFile(BibtexEntry entry, BibtexDatabase database, String directory,
 		String file, boolean relative) {
@@ -1014,25 +1245,25 @@ public class Util {
 			return null;
 
 		String found = findFile(entry, database, root, file);
-                
+
 		if (directory == null || !relative) {
 			return found;
 		}
-                
+
 		if (found != null) {
 			try {
 				/**
 				 * [ 1601651 ] PDF subdirectory - missing first character
-				 * 
+				 *
 				 * http://sourceforge.net/tracker/index.php?func=detail&aid=1601651&group_id=92314&atid=600306
 				 */
-                            // Changed by M. Alver 2007.01.04:
-                            // Remove first character if it is a directory separator character:
-                            String tmp = found.substring(root.getCanonicalPath().length());
-                            if ((tmp.length() > 1) && (tmp.charAt(0) == File.separatorChar))
-                                tmp = tmp.substring(1);
-                            return tmp;
-				//return found.substring(root.getCanonicalPath().length());
+                // Changed by M. Alver 2007.01.04:
+                // Remove first character if it is a directory separator character:
+                String tmp = found.substring(root.getCanonicalPath().length());
+                if ((tmp.length() > 1) && (tmp.charAt(0) == File.separatorChar))
+                    tmp = tmp.substring(1);
+                return tmp;
+                //return found.substring(root.getCanonicalPath().length());
 			} catch (IOException e) {
 				return null;
 			}
@@ -1180,9 +1411,9 @@ public class Util {
 	/**
 	 * Takes a string that contains bracketed expression and expands each of
 	 * these using getFieldAndFormat.
-	 * 
+	 *
 	 * Unknown Bracket expressions are silently dropped.
-	 * 
+	 *
 	 * @param bracketString
 	 * @param entry
 	 * @param database
@@ -1240,11 +1471,13 @@ public class Util {
 	public static File expandFilename(String name, String[] dir) {
 
 		for (int i = 0; i < dir.length; i++) {
-			File result = expandFilename(name, dir[i]);
-			if (result != null) {
-				return result;
-			}
-		}
+            if (dir[i] != null) {
+                File result = expandFilename(name, dir[i]);
+                if (result != null) {
+                    return result;
+                }
+            }
+        }
 
 		return null;
 	}
@@ -1273,7 +1506,8 @@ public class Util {
 				// if (name.startsWith("ftp"))
 
 				file = new File(name);
-				if (file.exists())
+
+                if (file.exists())
 					return file;
 				// Ok, try to fix / and \ problems:
 				if (Globals.ON_WIN) {
@@ -1340,10 +1574,11 @@ public class Util {
 		// The check if they have the same required fields:
 		String[] fields = one.getType().getRequiredFields();
 
-		if (fields == null)
-			return false;
-
-		float req = compareFieldSet(fields, one, two);
+        float req;
+        if (fields == null)
+			req = 1;
+        else
+            req = compareFieldSet(fields, one, two);
 		fields = one.getType().getOptionalFields();
 
 		if (fields != null) {
@@ -1447,18 +1682,20 @@ public class Util {
 			return ((double) score) / allFields.size();
 	}
 
-	/**
-	 * This methods assures all words in the given entry are recorded in their
-	 * respective Completers, if any.
-	 */
-	/*
-	 * public static void updateCompletersForEntry(Hashtable autoCompleters,
-	 * BibtexEntry be) {
-	 * 
-	 * for (Iterator j=autoCompleters.keySet().iterator(); j.hasNext();) {
-	 * String field = (String)j.next(); Completer comp =
-	 * (Completer)autoCompleters.get(field); comp.addAll(be.getField(field)); } }
-	 */
+    /**
+     * This methods assures all words in the given entry are recorded in their
+     * respective Completers, if any.
+     */
+    public static void updateCompletersForEntry(HashMap autoCompleters,
+                                                BibtexEntry be) {
+
+        for (Iterator j = autoCompleters.keySet().iterator(); j.hasNext();) {
+            String field = (String) j.next();
+            AutoCompleter comp = (AutoCompleter) autoCompleters.get(field);
+            comp.addAll(be.getField(field));
+        }
+    }
+
 
 	/**
 	 * Sets empty or non-existing owner fields of bibtex entries inside a List
@@ -1468,17 +1705,22 @@ public class Util {
 	 * @param bibs
 	 *            List of bibtex entries
 	 */
-	public static void setAutomaticFields(List bibs) {
+	public static void setAutomaticFields(List bibs, boolean overwriteOwner,
+             boolean overwriteTimestamp) {
 		String defaultOwner = Globals.prefs.get("defaultOwner");
 		String timestamp = easyDateFormat();
-		boolean setOwner = Globals.prefs.getBoolean("useOwner"), setTimeStamp = Globals.prefs
-			.getBoolean("useTimeStamp");
+		boolean globalSetOwner = Globals.prefs.getBoolean("useOwner"),
+                globalSetTimeStamp = Globals.prefs.getBoolean("useTimeStamp");
 		String timeStampField = Globals.prefs.get("timeStampField");
 		// Iterate through all entries
 		for (int i = 0; i < bibs.size(); i++) {
 			// Get current entry
 			BibtexEntry curEntry = (BibtexEntry) bibs.get(i);
-			setAutomaticFields(curEntry, setOwner, defaultOwner, setTimeStamp, timeStampField,
+            boolean setOwner = globalSetOwner &&
+                (overwriteOwner || (curEntry.getField(BibtexFields.OWNER)==null));
+            boolean setTimeStamp = globalSetTimeStamp &&
+                (overwriteTimestamp || (curEntry.getField(timeStampField)==null));
+            setAutomaticFields(curEntry, setOwner, defaultOwner, setTimeStamp, timeStampField,
 				timestamp);
 
 		}
@@ -1492,13 +1734,21 @@ public class Util {
 	 * 
 	 * @param entry
 	 *            The entry to set fields for.
+     * @param overwriteOwner
+     *              Indicates whether owner should be set if it is already set.
+     * @param overwriteTimestamp
+     *              Indicates whether timestamp should be set if it is already set.
 	 */
-	public static void setAutomaticFields(BibtexEntry entry) {
+	public static void setAutomaticFields(BibtexEntry entry, boolean overwriteOwner,
+                                          boolean overwriteTimestamp) {
 		String defaultOwner = Globals.prefs.get("defaultOwner");
 		String timestamp = easyDateFormat();
-		boolean setOwner = Globals.prefs.getBoolean("useOwner"), setTimeStamp = Globals.prefs
-			.getBoolean("useTimeStamp");
-		String timeStampField = Globals.prefs.get("timeStampField");
+        String timeStampField = Globals.prefs.get("timeStampField");
+        boolean setOwner = Globals.prefs.getBoolean("useOwner") &&
+            (overwriteOwner || (entry.getField(BibtexFields.OWNER)==null));
+        boolean setTimeStamp = Globals.prefs.getBoolean("useTimeStamp") &&
+            (overwriteTimestamp || (entry.getField(timeStampField)==null));
+
 		setAutomaticFields(entry, setOwner, defaultOwner, setTimeStamp, timeStampField, timestamp);
 	}
 
@@ -1595,7 +1845,54 @@ public class Util {
 
 	}
 
-	// -------------------------------------------------------------------------------
+    /**
+     * Collect file links from the given set of fields, and add them to the list contained
+     * in the field GUIGlobals.FILE_FIELD.
+     * @param database The database to modify.
+     * @param fields The fields to find links in.
+     * @return A CompoundEdit specifying the undo operation for the whole operation.
+     */
+    public static NamedCompound upgradePdfPsToFile(BibtexDatabase database, String[] fields) {
+        NamedCompound ce = new NamedCompound(Globals.lang("Move external links to 'file' field"));
+        for (Iterator i = database.getEntryMap().keySet().iterator(); i.hasNext();) {
+            BibtexEntry entry = (BibtexEntry) database.getEntryMap().get(i.next());
+            FileListTableModel tableModel = new FileListTableModel();
+            // If there are already links in the file field, keep those on top:
+            Object oldFileContent = entry.getField(GUIGlobals.FILE_FIELD);
+            if (oldFileContent != null) {
+                tableModel.setContent((String) oldFileContent);
+            }
+            int oldRowCount = tableModel.getRowCount();
+            for (int j = 0; j < fields.length; j++) {
+                Object o = entry.getField(fields[j]);
+                if (o != null) {
+                    String s = (String) o;
+                    if (s.trim().length() > 0) {
+                        File f = new File(s);
+                        String extension = "";
+                        if ((s.lastIndexOf('.') >= 0) && (s.lastIndexOf('.') < s.length() - 1)) {
+                            extension = s.substring(s.lastIndexOf('.') + 1);
+                        }
+                        FileListEntry flEntry = new FileListEntry(f.getName(), s,
+                                Globals.prefs.getExternalFileTypeByExt(fields[j]));
+                        tableModel.addEntry(tableModel.getRowCount(), flEntry);
+                        
+                        entry.clearField(fields[j]);
+                        ce.addEdit(new UndoableFieldChange(entry, fields[j], o, null));
+                    }
+                }
+            }
+            if (tableModel.getRowCount() != oldRowCount) {
+                String newValue = tableModel.getStringRepresentation();
+                entry.setField(GUIGlobals.FILE_FIELD, newValue);
+                ce.addEdit(new UndoableFieldChange(entry, GUIGlobals.FILE_FIELD, oldFileContent, newValue));
+            }
+        }
+        ce.end();
+        return ce;
+    }
+
+    // -------------------------------------------------------------------------------
 
 	/**
 	 * extends the filename with a default Extension, if no Extension '.x' could
@@ -2294,4 +2591,112 @@ public class Util {
 		}
 		return -1;
 	}
-}
\ No newline at end of file
+
+
+    /**
+     * Encodes a two-dimensional String array into a single string, using ':' and
+     * ';' as separators. The characters ':' and ';' are escaped with '\'.
+     * @param values The String array.
+     * @return The encoded String.
+     */
+    public static String encodeStringArray(String[][] values) {
+        StringBuilder sb = new StringBuilder();
+        for (int i = 0; i < values.length; i++) {
+            sb.append(encodeStringArray(values[i]));
+            if (i < values.length-1)
+                sb.append(';');
+        }
+        return sb.toString();
+    }
+
+    /**
+     * Encodes a String array into a single string, using ':' as separator.
+     * The characters ':' and ';' are escaped with '\'.
+     * @param entry The String array.
+     * @return The encoded String.
+     */
+    public static String encodeStringArray(String[] entry) {
+        StringBuilder sb = new StringBuilder();
+        for (int i = 0; i < entry.length; i++) {
+            sb.append(encodeString(entry[i]));
+            if (i < entry.length-1)
+                sb.append(':');
+
+        }
+        return sb.toString();
+    }
+
+    /**
+     * Decodes an encoded double String array back into array form. The array
+     * is assumed to be square, and delimited by the characters ';' (first dim) and
+     * ':' (second dim).
+     * @param value The encoded String to be decoded.
+     * @return The decoded String array.
+     */
+    public static String[][] decodeStringDoubleArray(String value) {
+        ArrayList<ArrayList<String>> newList = new ArrayList<ArrayList<String>>();
+        StringBuilder sb = new StringBuilder();
+        ArrayList<String> thisEntry = new ArrayList<String>();
+        boolean escaped = false;
+        for (int i=0; i<value.length(); i++) {
+            char c = value.charAt(i);
+            if (!escaped && (c == '\\')) {
+                escaped = true;
+                continue;
+            }
+            else if (!escaped && (c == ':')) {
+                thisEntry.add(sb.toString());
+                sb = new StringBuilder();
+            }
+            else if (!escaped && (c == ';')) {
+                thisEntry.add(sb.toString());
+                sb = new StringBuilder();
+                newList.add(thisEntry);
+                thisEntry = new ArrayList<String>();
+            }
+            else sb.append(c);
+            escaped = false;
+        }
+        if (sb.length() > 0)
+            thisEntry.add(sb.toString());
+        if (thisEntry.size() > 0)
+            newList.add(thisEntry);
+
+        // Convert to String[][]:
+        String[][] res = new String[newList.size()][];
+        for (int i = 0; i < res.length; i++) {
+            res[i] = new String[newList.get(i).size()];
+            for (int j = 0; j < res[i].length; j++) {
+                res[i][j] = newList.get(i).get(j);
+            }
+        }
+        return res;
+    }
+
+    private static String encodeString(String s) {
+        StringBuilder sb = new StringBuilder();
+        for (int i=0; i<s.length(); i++) {
+            char c = s.charAt(i);
+            if ((c == ';') || (c == ':') || (c == '\\'))
+                sb.append('\\');
+            sb.append(c);
+        }
+        return sb.toString();
+    }
+
+    /**
+	 * Static equals that can also return the right result when one of the
+	 * objects is null.
+	 * 
+	 * @param one
+	 *            The object whose equals method is called if the first is not
+	 *            null.
+	 * @param two
+	 *            The object passed to the first one if the first is not null.
+	 * @return <code>one == null ? two == null : one.equals(two);</code>
+	 */
+	public static boolean equals(Object one, Object two) {
+		return one == null ? two == null : one.equals(two);
+	}
+
+}
