@@ -120,8 +120,10 @@ public class FileActions
      * @param encoding String the name of the encoding, which is part of the header.
      */
     private static void writeBibFileHeader(Writer out, String encoding) throws IOException {
+        out.write("% ");
       out.write(GUIGlobals.SIGNATURE);
-      out.write(" "+GUIGlobals.version+"."+Globals.NEWLINE +GUIGlobals.encPrefix+encoding+Globals.NEWLINE +Globals.NEWLINE);
+      out.write(" "+GUIGlobals.version+"."+Globals.NEWLINE + "% " + 
+              GUIGlobals.encPrefix+encoding+Globals.NEWLINE +Globals.NEWLINE);
     }
 
     /**
@@ -239,7 +241,7 @@ public class FileActions
                 e.printStackTrace();
                 throw new SaveException(ex.getMessage()+"\n"+
                         Globals.lang("Warning: could not complete file repair; your file may "
-                        +"have been corrupted. Error message: ")+e.getMessage());
+                        +"have been corrupted. Error message")+": "+e.getMessage());
             }
             throw new SaveException(ex.getMessage(), be);
     }
@@ -431,11 +433,8 @@ public class FileActions
                                    HashMap fieldFormatters, Writer out)
     throws IOException {
 
-    String s = (String)entry.getField(field);
-    if (s == null) {
-        return;
-    }
-        s = database.resolveForStrings(s);
+    String s = BibtexDatabase.getResolvedField(field, entry, database);
+    	
     Object form = fieldFormatters.get(field);
     if (form == null)
         form = fieldFormatters.get("default");
