@@ -42,7 +42,7 @@ import wsi.ra.types.StringInt;
  * DOCUMENT ME!
  * 
  * @author $author$
- * @version $Revision: 1.16 $
+ * @version $Revision: 2331 $
  */
 public class LayoutEntry {
 	// ~ Instance fields
@@ -101,8 +101,8 @@ public class LayoutEntry {
 		String blockStart = null;
 		String blockEnd = null;
 		StringInt si;
-		Vector blockEntries = null;
-		Vector tmpEntries = new Vector();
+		Vector<StringInt> blockEntries = null;
+		Vector<LayoutEntry> tmpEntries = new Vector<LayoutEntry>();
 		LayoutEntry le;
 		si = (StringInt) parsedEntries.get(0);
 		blockStart = si.s;
@@ -124,7 +124,7 @@ public class LayoutEntry {
 			} else if (si.i == LayoutHelper.IS_SIMPLE_FIELD) {
 			} else if ((si.i == LayoutHelper.IS_FIELD_START)
 				|| (si.i == LayoutHelper.IS_GROUP_START)) {
-				blockEntries = new Vector();
+				blockEntries = new Vector<StringInt>();
 				blockStart = si.s;
 			} else if ((si.i == LayoutHelper.IS_FIELD_END) || (si.i == LayoutHelper.IS_GROUP_END)) {
 				if (blockStart.equals(si.s)) {
@@ -167,10 +167,10 @@ public class LayoutEntry {
 		case LayoutHelper.IS_LAYOUT_TEXT:
 			return text;
 		case LayoutHelper.IS_SIMPLE_FIELD:
-			return getField(bibtex, text, database);
+			return BibtexDatabase.getResolvedField(text, bibtex, database);
 		case LayoutHelper.IS_FIELD_START:
 		case LayoutHelper.IS_GROUP_START: {
-			String field = getField(bibtex, text, database);
+			String field = BibtexDatabase.getResolvedField(text, bibtex, database);
 
 			if ((field == null)
 				|| ((type == LayoutHelper.IS_GROUP_START) && (field.equalsIgnoreCase(LayoutHelper
@@ -233,8 +233,8 @@ public class LayoutEntry {
 			} else {
 				// changed section begin - arudert
 				// resolve field (recognized by leading backslash) or text
-				String field = text.startsWith("\\") ? getField(bibtex, text.substring(1), database)
-					: getText(text, database);
+				String field = text.startsWith("\\") ? BibtexDatabase.getResolvedField(text.substring(1), bibtex, database)
+					: BibtexDatabase.getText(text, database);
 				// changed section end - arudert
 				if (field == null) {
 					fieldEntry = "";
@@ -252,7 +252,13 @@ public class LayoutEntry {
 
 			return fieldEntry;
 		}
-		default:
+        case LayoutHelper.IS_ENCODING_NAME: {
+            // Printing the encoding name is not supported in entry layouts, only
+            // in begin/end layouts. This prevents breakage if some users depend
+            // on a field called "encoding". We simply return this field instead:
+            return BibtexDatabase.getResolvedField("encoding", bibtex, database);
+        }
+        default:
 			return "";
 		}
 	}
@@ -265,12 +271,12 @@ public class LayoutEntry {
 	 *            Bibtex Database
 	 * @return
 	 */
-	public String doLayout(BibtexDatabase database) {
+	public String doLayout(BibtexDatabase database, String encoding) {
 		if (type == LayoutHelper.IS_LAYOUT_TEXT) {
 			return text;
 		} else if (type == LayoutHelper.IS_SIMPLE_FIELD) {
 			throw new UnsupportedOperationException(
-				"bibtext entry fields not allowed in begin or end layout");
+				"bibtex entry fields not allowed in begin or end layout");
 		} else if ((type == LayoutHelper.IS_FIELD_START) || (type == LayoutHelper.IS_GROUP_START)) {
 			throw new UnsupportedOperationException(
 				"field and group starts not allowed in begin or end layout");
@@ -278,7 +284,7 @@ public class LayoutEntry {
 			throw new UnsupportedOperationException(
 				"field and group ends not allowed in begin or end layout");
 		} else if (type == LayoutHelper.IS_OPTION_FIELD) {
-			String field = getText(text, database);
+			String field = BibtexDatabase.getText(text, database);
 			if (option != null) {
 				for (int i = 0; i < option.length; i++) {
 					field = option[i].format(field);
@@ -286,7 +292,11 @@ public class LayoutEntry {
 			}
 
 			return field;
-		}
+		} else if (type == LayoutHelper.IS_ENCODING_NAME) {
+            // Try to translate from Java encoding name to common name:
+            String commonName = Globals.ENCODING_NAMES_LOOKUP.get(encoding);
+            return commonName != null ? commonName : encoding;
+        }
 		return "";
 	}
 
@@ -295,8 +305,7 @@ public class LayoutEntry {
 	public static LayoutFormatter getLayoutFormatter(String className, String classPrefix)
 		throws Exception {
 		LayoutFormatter f = null;
-
-		if (className.length() > 0) {
+        if (className.length() > 0) {
 			try {
 				try {
 					f = (LayoutFormatter) Class.forName(classPrefix + className).newInstance();
@@ -324,7 +333,7 @@ public class LayoutEntry {
 
 		ArrayList formatterStrings = Util.parseMethodsCalls(formatterName);
 
-		ArrayList results = new ArrayList(formatterStrings.size());
+		ArrayList<LayoutFormatter> results = new ArrayList<LayoutFormatter>(formatterStrings.size());
 
 		Map userNameFormatter = NameFormatterTab.getNameFormatters();
 
@@ -334,9 +343,15 @@ public class LayoutEntry {
 
 			String className = strings[0].trim();
 
-			try {
+            try {
 				LayoutFormatter f = getLayoutFormatter(className, classPrefix);
-				results.add(f);
+                // If this formatter accepts an argument, check if we have one, and
+                // set it if so:
+                if (f instanceof ParamLayoutFormatter) {
+                    if (strings.length >= 2)
+                        ((ParamLayoutFormatter)f).setArgument(strings[1]);
+                }
+                results.add(f);
 			} catch (Exception e) {
 
 				String formatterParameter = (String) userNameFormatter.get(className);
@@ -354,41 +369,4 @@ public class LayoutEntry {
 		return (LayoutFormatter[]) results.toArray(new LayoutFormatter[] {});
 	}
 
-	// changed section begin - arudert
-	/**
-	 * Returns a text with references resolved according to an optionally given
-	 * database.
-	 */
-	private String getText(String text, BibtexDatabase database) {
-		String res = text;
-		// changed section end - arudert
-		if ((res != null) && (database != null))
-			res = database.resolveForStrings(res);
-		return res;
-	}
-
-	// changed section end - arudert
-
-	private String getField(BibtexEntry bibtex, String field, BibtexDatabase database) {
-
-		// Change: Morten Alver, May 23, 2006. Formatter argument uses this
-		// method to
-		// resolve field values. We need this part to resolve \bibtextype
-		// correctly in
-		// constructs like \format[ToLowerCase]{\bibtextype}:
-		if (field.equals("bibtextype")) {
-			return bibtex.getType().getName();
-		}
-		// end change Morten Alver
-
-		String res = (String) bibtex.getField(field);
-
-		if ((res != null) && (database != null))
-			res = database.resolveForStrings(res);
-
-		return res;
-	}
-}
-// /////////////////////////////////////////////////////////////////////////////
-// END OF FILE.
-// /////////////////////////////////////////////////////////////////////////////
+}
\ No newline at end of file
