@@ -12,13 +12,18 @@ import net.sf.jabref.export.layout.LayoutFormatter;
  * 
  * TODO Search also relative to Bib-file.
  * 
- * @author $Author: coezbek $
- * @version $Revision: 1.5 $ ($Date: 2006/08/27 21:04:28 $)
+ * @author $Author: mortenalver $
+ * @version $Revision: 2181 $ ($Date: 2007-07-11 22:31:20 +0200 (Wed, 11 Jul 2007) $)
  */
 public class ResolvePDF implements LayoutFormatter {
 
 	public String format(String field) {
-		String dir = Globals.prefs.get("pdfDirectory");
+
+        // Search in the standard PDF directory:
+        /* TODO: oops, this part is not sufficient. We need access to the
+          database's metadata in order to check if the database overrides
+          the standard file directory */
+        String dir = Globals.prefs.get("pdfDirectory");
 		File f = Util.expandFilename(field, new String[] { dir, "." });
 		
 		/*
@@ -26,7 +31,7 @@ public class ResolvePDF implements LayoutFormatter {
 		 * 
 		 * https://sourceforge.net/tracker/index.php?func=detail&aid=1469903&group_id=92314&atid=600306
 		 */
-		if (f != null){
+		if (f != null) {
 			return f.toURI().toString();
 		} else {
 			return field;
