@@ -10,7 +10,6 @@ import java.io.File;
 import java.awt.*;
 import java.awt.event.ActionListener;
 import java.awt.event.ActionEvent;
-import java.util.Vector;
 import java.util.Collection;
 
 import com.jgoodies.forms.layout.FormLayout;
@@ -30,12 +29,13 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
     private OptionsDialog optDiag = null;
 
     Object[] brokenLinkOptions =
-        { Globals.lang("Ignore"), Globals.lang("Assign new file"), Globals.lang("Clear field"),
-            Globals.lang("Quit synchronization")};
+            {Globals.lang("Ignore"), Globals.lang("Assign new file"), Globals.lang("Clear field"),
+                    Globals.lang("Quit synchronization")};
 
     private boolean goOn = true, autoSet = true, overWriteAllowed = true, checkExisting = true;
 
-    private int skipped=0, entriesChanged=0, brokenLinks=0;
+    private int skipped = 0, entriesChanged = 0, brokenLinks = 0;
+
 
     public AutoSetExternalFileForEntries(BasePanel panel, String fieldName) {
         this.fieldName = fieldName;
@@ -43,16 +43,17 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
     }
 
     public void init() {
-        // Get all entries, and make sure there are selected entries:
+        /*// Get all entries, and make sure there are selected entries:
     	sel = panel.getSelectedEntries();
     	if (sel.length < 1) {
 	    // No entries selected. Assume all entries should be treated:
-	    Collection col = panel.database().getEntries();
-	    sel = new BibtexEntry[col.size()];
-	    sel = (BibtexEntry[])col.toArray(sel);
-            //goOn = false;
-            //return;
-        }
+	    */
+        Collection col = panel.database().getEntries();
+        sel = new BibtexEntry[col.size()];
+        sel = (BibtexEntry[]) col.toArray(sel);
+        //goOn = false;
+        //return;
+        //}
 
         // Ask about rules for the operation:
         if (optDiag == null)
@@ -71,20 +72,20 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
     }
 
     public void run() {
-        if (!goOn){
+        if (!goOn) {
             panel.output(Globals.lang("No entries selected."));
             return;
         }
-	panel.frame().setProgressBarValue(0);
-	panel.frame().setProgressBarVisible(true);
-	int weightAutoSet = 10; // autoSet takes 10 (?) times longer than checkExisting
-	int progressBarMax = (autoSet ? weightAutoSet*sel.length : 0) 
-	    + (checkExisting ? sel.length : 0);
-	panel.frame().setProgressBarMaximum(progressBarMax);
-	int progress = 0;
-        skipped=0;
-        entriesChanged=0;
-        brokenLinks=0;
+        panel.frame().setProgressBarValue(0);
+        panel.frame().setProgressBarVisible(true);
+        int weightAutoSet = 10; // autoSet takes 10 (?) times longer than checkExisting
+        int progressBarMax = (autoSet ? weightAutoSet * sel.length : 0)
+                + (checkExisting ? sel.length : 0);
+        panel.frame().setProgressBarMaximum(progressBarMax);
+        int progress = 0;
+        skipped = 0;
+        entriesChanged = 0;
+        brokenLinks = 0;
         NamedCompound ce = new NamedCompound(Globals.lang("Autoset %0 field", fieldName));
 
         final OpenFileFilter off = Util.getFileFilterForField(fieldName);
@@ -97,16 +98,16 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
 
         // First we try to autoset fields
         if (autoSet) {
-            for (int i=0; i<sel.length; i++) {
-		progress += weightAutoSet;
-		panel.frame().setProgressBarValue(progress);
+            for (int i = 0; i < sel.length; i++) {
+                progress += weightAutoSet;
+                panel.frame().setProgressBarValue(progress);
 
                 final Object old = sel[i].getField(fieldName);
-                // Check if a link is already set, and if so, if we are allowed to overwrite it:
+                // Check if a extension is already set, and if so, if we are allowed to overwrite it:
                 if ((old != null) && !old.equals("") && !overWriteAllowed)
                     continue;
-                extPan.setEntry(sel[i]);
-                editor.setText((old != null) ? (String)old : "");
+                extPan.setEntry(sel[i], panel.getDatabase());
+                editor.setText((old != null) ? (String) old : "");
                 Thread t = extPan.autoSetFile(fieldName, editor);
                 // Wait for the autoset process to finish:
                 if (t != null)
@@ -128,23 +129,24 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
         //System.out.println("Done setting");
         // The following loop checks all external links that are already set.
         if (checkExisting) {
-            mainLoop: for (int i=0; i<sel.length; i++) {
-		panel.frame().setProgressBarValue(progress++);
+            mainLoop:
+            for (int i = 0; i < sel.length; i++) {
+                panel.frame().setProgressBarValue(progress++);
                 final Object old = sel[i].getField(fieldName);
-                // Check if a link is set:
-                if ((old != null) && !((String)old).equals("")) {
+                // Check if a extension is set:
+                if ((old != null) && !((String) old).equals("")) {
                     // Get an absolute path representation:
-                    File file = Util.expandFilename((String)old, new String[]{dir, "."});;
+                    File file = Util.expandFilename((String) old, new String[]{dir, "."});
 
                     if ((file == null) || !file.exists()) {
 
                         int answer =
-                            JOptionPane.showOptionDialog(panel.frame(),
-                            Globals.lang("<HTML>Could not find file '%0'<BR>linked from entry '%1'</HTML>",
-                                new String[] {(String)old, sel[i].getCiteKey()}),
-                                    Globals.lang("Broken link"),
-                                    JOptionPane.YES_NO_CANCEL_OPTION,
-                                    JOptionPane.QUESTION_MESSAGE, null, brokenLinkOptions, brokenLinkOptions[0]);
+                                JOptionPane.showOptionDialog(panel.frame(),
+                                        Globals.lang("<HTML>Could not find file '%0'<BR>linked from entry '%1'</HTML>",
+                                                new String[]{(String) old, sel[i].getCiteKey()}),
+                                        Globals.lang("Broken link"),
+                                        JOptionPane.YES_NO_CANCEL_OPTION,
+                                        JOptionPane.QUESTION_MESSAGE, null, brokenLinkOptions, brokenLinkOptions[0]);
                         switch (answer) {
                             case 1:
                                 // Assign new file.
@@ -159,7 +161,7 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
                                 }
                                 break;
                             case 2:
-                                 // Clear field
+                                // Clear field
                                 ce.addEdit(new UndoableFieldChange(sel[i], fieldName, old, null));
                                 sel[i].setField(fieldName, null);
                                 entriesChanged++;
@@ -183,23 +185,24 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
         }
     }
 
+
     public void update() {
         if (!goOn)
             return;
 
         panel.output(Globals.lang("Finished synchronizing %0 links. Entries changed%c %1.",
-                new String[] {fieldName.toUpperCase(), String.valueOf(entriesChanged)}));
-	panel.frame().setProgressBarVisible(false);
+                new String[]{fieldName.toUpperCase(), String.valueOf(entriesChanged)}));
+        panel.frame().setProgressBarVisible(false);
         if (entriesChanged > 0) {
             panel.markBaseChanged();
         }
     }
 
-    static class OptionsDialog extends JDialog {
+    class OptionsDialog extends JDialog {
         JRadioButton autoSetUnset, autoSetAll, autoSetNone;
         JCheckBox checkLinks;
         JButton ok = new JButton(Globals.lang("Ok")),
-            cancel = new JButton(Globals.lang("Cancel"));
+                cancel = new JButton(Globals.lang("Cancel"));
         JLabel description;
         private boolean canceled = true;
         private String fieldName;
@@ -208,14 +211,14 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
             super(parent, Globals.lang("Synchronize %0 links", fieldName.toUpperCase()), true);
             final String fn = fieldName.toUpperCase();
             this.fieldName = fieldName;
-            ok.addActionListener(new ActionListener () {
+            ok.addActionListener(new ActionListener() {
                 public void actionPerformed(ActionEvent e) {
                     canceled = false;
                     dispose();
                 }
             });
 
-            Action closeAction = new AbstractAction () {
+            Action closeAction = new AbstractAction() {
                 public void actionPerformed(ActionEvent e) {
                     dispose();
                 }
@@ -225,27 +228,27 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
             cancel.addActionListener(closeAction);
 
             InputMap im = cancel.getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW);
-	        ActionMap am = cancel.getActionMap();
+            ActionMap am = cancel.getActionMap();
             im.put(Globals.prefs.getKey("Close dialog"), "close");
-	        am.put("close", closeAction);
+            am.put("close", closeAction);
 
             fieldName = fieldName.toUpperCase();
-            autoSetUnset =  new JRadioButton(Globals.lang("Autoset %0 links. Do not overwrite existing links.", fn), true);
-            autoSetAll =  new JRadioButton(Globals.lang("Autoset %0 links. Allow overwriting existing links.", fn), false);
-            autoSetNone =  new JRadioButton(Globals.lang("Do not autoset"), false);
+            autoSetUnset = new JRadioButton(Globals.lang("Autoset %0 links. Do not overwrite existing links.", fn), true);
+            autoSetAll = new JRadioButton(Globals.lang("Autoset %0 links. Allow overwriting existing links.", fn), false);
+            autoSetNone = new JRadioButton(Globals.lang("Do not autoset"), false);
             checkLinks = new JCheckBox(Globals.lang("Check existing %0 links", fn), true);
             ButtonGroup bg = new ButtonGroup();
             bg.add(autoSetUnset);
             bg.add(autoSetNone);
             bg.add(autoSetAll);
-            FormLayout layout = new FormLayout("fill:pref","");
-	        DefaultFormBuilder builder = new DefaultFormBuilder(layout);
-            description = new JLabel("<HTML>"+
+            FormLayout layout = new FormLayout("fill:pref", "");
+            DefaultFormBuilder builder = new DefaultFormBuilder(layout);
+            description = new JLabel("<HTML>" +
                     Globals.lang(//"This function helps you keep your external %0 links up-to-date." +
                             "Attempt to autoset %0 links for your entries. Autoset works if "
-                            +"a %0 file in your %0 directory or a subdirectory<BR>is named identically to an entry's BibTeX key, plus extension.", fn)
-                    +"</HTML>");
-            //            description.setVerticalAlignment(JLabel.TOP);
+                                    + "a %0 file in your %0 directory or a subdirectory<BR>is named identically to an entry's BibTeX key, plus extension.", fn)
+                    + "</HTML>");
+            //            name.setVerticalAlignment(JLabel.TOP);
             builder.appendSeparator(Globals.lang("Autoset"));
             builder.append(description);
             builder.nextLine();
@@ -257,10 +260,10 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
             builder.nextLine();
             builder.appendSeparator(Globals.lang("Check links"));
 
-            description = new JLabel("<HTML>"+
-                    Globals.lang("This makes JabRef look up each %0 link and check if the file exists. If not, you will "
-                                    +"be given options<BR>to resolve the problem.", fn)
-                +"</HTML>");
+            description = new JLabel("<HTML>" +
+                    Globals.lang("This makes JabRef look up each %0 extension and check if the file exists. If not, you will "
+                            + "be given options<BR>to resolve the problem.", fn)
+                    + "</HTML>");
             builder.append(description);
             builder.nextLine();
             builder.append(checkLinks);
@@ -268,9 +271,8 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
             builder.appendSeparator();
 
 
-
             JPanel main = builder.getPanel();
-            main.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
+            main.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
 
             ButtonBarBuilder bb = new ButtonBarBuilder();
             bb.addGlue();
@@ -287,15 +289,15 @@ public class AutoSetExternalFileForEntries extends AbstractWorker {
             if (visible)
                 canceled = true;
 
-            String dir = Globals.prefs.get(fieldName+"Directory");
+            String dir = panel.metaData().getFileDirectory(fieldName);
+
             if ((dir == null) || (dir.trim().length() == 0)) {
 
                 autoSetNone.setSelected(true);
                 autoSetNone.setEnabled(false);
                 autoSetAll.setEnabled(false);
                 autoSetUnset.setEnabled(false);
-            }
-            else {
+            } else {
                 autoSetNone.setEnabled(true);
                 autoSetAll.setEnabled(true);
                 autoSetUnset.setEnabled(true);
