@@ -1,6 +1,8 @@
 package net.sf.jabref.gui;
 
 import net.sf.jabref.*;
+import net.sf.jabref.external.DownloadExternalFile;
+import net.sf.jabref.external.ExternalFileMenuItem;
 import net.sf.jabref.groups.GroupTreeNode;
 import net.sf.jabref.groups.AllEntriesGroup;
 import net.sf.jabref.groups.AbstractGroup;
@@ -19,6 +21,7 @@ import java.util.*;
 import java.util.List;
 import java.awt.*;
 import java.awt.event.*;
+import java.io.IOException;
 
 import com.jgoodies.forms.builder.ButtonBarBuilder;
 import com.jgoodies.forms.builder.ButtonStackBuilder;
@@ -36,8 +39,8 @@ import ca.odell.glazedlists.swing.EventSelectionModel;
  * Dialog to allow the selection of entries as part of an Import
  * 
  * @author alver
- * @author $Author: coezbek $
- * @version $Revision: 1.27 $ ($Date: 2006/12/04 14:37:01 $)
+ * @author $Author: mortenalver $
+ * @version $Revision: 2458 $ ($Date: 2007-11-04 15:47:55 +0100 (Sun, 04 Nov 2007) $)
  *
  */
 public class ImportInspectionDialog extends JDialog {
@@ -77,16 +80,18 @@ public class ImportInspectionDialog extends JDialog {
     private JCheckBox autoGenerate = new JCheckBox(Globals.lang("Generate keys"), Globals.prefs.getBoolean("generateKeysAfterInspection"));
     private JLabel
         duplLabel = new JLabel(GUIGlobals.getImage("duplicate")),
+        fileLabel = new JLabel(GUIGlobals.getImage("psSmall")),
         pdfLabel = new JLabel(GUIGlobals.getImage("pdfSmall")),
         psLabel = new JLabel(GUIGlobals.getImage("psSmall")),
         urlLabel = new JLabel(GUIGlobals.getImage("wwwSmall"));
 
     private final int
         DUPL_COL = 1,
-        PDF_COL = 2,
-        PS_COL = 3,
-        URL_COL = 4,
-        PAD = 5;
+        FILE_COL = 2,
+        PDF_COL = -1,//3,
+        PS_COL = -2,//4,
+        URL_COL = 3,//5,
+        PAD = 4; // 6;
 
     /**
      * The "defaultSelected" boolean value determines if new entries added are selected for import or not.
@@ -122,7 +127,7 @@ public class ImportInspectionDialog extends JDialog {
         EventTableModel tableModelGl = new EventTableModel(sortedList,
                 new EntryTableFormat());
         glTable = new EntryTable(tableModelGl);
-        GeneralRenderer renderer = new GeneralRenderer(Color.white, true);
+        GeneralRenderer renderer = new GeneralRenderer(Color.white);
         glTable.setDefaultRenderer(JLabel.class, renderer);
         glTable.setDefaultRenderer(String.class, renderer);
         glTable.getInputMap().put(Globals.prefs.getKey("Delete"), "delete");
@@ -160,8 +165,11 @@ public class ImportInspectionDialog extends JDialog {
         }
 
         // Add "Attach file" menu choices to right click menu:
-        popup.add(new AttachFile("pdf"));
-        popup.add(new AttachFile("ps"));
+        popup.add(new LinkLocalFile());
+        popup.add(new DownloadFile());
+        popup.add(new AutoSetLinks());
+        //popup.add(new AttachFile("pdf"));
+        //popup.add(new AttachFile("ps"));
         popup.add(new AttachUrl());
         getContentPane().add(centerPan, BorderLayout.CENTER);
 
@@ -201,8 +209,22 @@ public class ImportInspectionDialog extends JDialog {
         delete.addActionListener(deleteListener);
         help.addActionListener(new HelpAction(frame.helpDiag, GUIGlobals.importInspectionHelp));
         getContentPane().add(bb.getPanel(), BorderLayout.SOUTH);
-        setSize(new Dimension(650, 650));
-        //contentPane.setDividerLocation(0.6f);
+
+        // Remember and default to last size:
+        setSize(new Dimension(Globals.prefs.getInt("importInspectionDialogWidth"),
+                Globals.prefs.getInt("importInspectionDialogHeight")));
+        addWindowListener(new WindowAdapter() {
+
+            public void windowOpened(WindowEvent e) {
+                contentPane.setDividerLocation(0.5f);
+            }
+
+            public void windowClosed(WindowEvent e) {
+                Globals.prefs.putInt("importInspectionDialogWidth", getSize().width);
+                Globals.prefs.putInt("importInspectionDialogHeight", getSize().height);
+            }
+        });
+
     }
 
     public void setProgress(int current, int max) {
@@ -324,6 +346,38 @@ public class ImportInspectionDialog extends JDialog {
         return selected;
     }
 
+    /**
+     * Generate key for the selected entry only.
+     */
+    public void generateKeySelectedEntry() {
+        if (selectionModel.getSelected().size() != 1)
+                return;
+        BibtexEntry entry = (BibtexEntry) selectionModel.getSelected().get(0);
+        entries.getReadWriteLock().writeLock().lock();
+        BibtexDatabase database = null;
+        // Relate to the existing database, if any:
+        if (panel != null)
+            database = panel.database();
+        // ... or create a temporary one:
+        else
+            database = new BibtexDatabase();
+        try {
+            entry.setId(Util.createNeutralId());
+            // Add the entry to the database we are working with:
+            database.insertEntry(entry);
+        } catch (KeyCollisionException ex) {
+            ex.printStackTrace();
+        }
+        // Generate a unique key:
+        LabelPatternUtil.makeLabel(Globals.prefs.getKeyPattern(), database, entry);
+        // Remove the entry from the database again, since we only added it in order to
+        // make sure the key was unique:
+        database.removeEntry(entry.getId());
+        
+        entries.getReadWriteLock().writeLock().lock();
+        glTable.repaint();
+    }
+
     /**
      * Generate keys for all entries. All keys will be unique with respect to one another,
      * and, if they are destined for an existing database, with respect to existing keys in
@@ -522,7 +576,8 @@ public class ImportInspectionDialog extends JDialog {
                 boolean groupingCanceled = false;
 
                 // Set owner/timestamp if options are enabled:
-                Util.setAutomaticFields(selected);
+                Util.setAutomaticFields(selected, Globals.prefs.getBoolean("overwriteOwner"),
+                    Globals.prefs.getBoolean("overwriteTimeStamp"));
 
 
                 for (Iterator i = selected.iterator(); i.hasNext();) {
@@ -570,6 +625,8 @@ public class ImportInspectionDialog extends JDialog {
                     try {
                         entry.setId(Util.createNeutralId());
                         panel.database().insertEntry(entry);
+                        // Let the autocompleters, if any, harvest words from the entry: 
+                        Util.updateCompletersForEntry(panel.getAutoCompleters(), entry);
                         ce.addEdit(new UndoableInsertEntry(panel.database(), entry, panel));
                     } catch (KeyCollisionException e) {
                         e.printStackTrace();
@@ -729,8 +786,41 @@ public class ImportInspectionDialog extends JDialog {
      */
     class TableClickListener implements MouseListener {
 
-        public void mouseClicked(MouseEvent e) {
+        public boolean isIconColumn(int col) {
+            return (col == FILE_COL) || (col == PDF_COL) || (col == PS_COL)
+                    || (col == URL_COL);
+        }
 
+        public void mouseClicked(MouseEvent e) {
+            final int col = glTable.columnAtPoint(e.getPoint()),
+              row = glTable.rowAtPoint(e.getPoint());
+            if (isIconColumn(col)) {
+                BibtexEntry entry = (BibtexEntry)sortedList.get(row);
+
+                switch (col) {
+                    case FILE_COL:
+                        Object o = entry.getField(GUIGlobals.FILE_FIELD);
+                        if (o != null) {
+                            FileListTableModel tableModel = new FileListTableModel();
+                            tableModel.setContent((String)o);
+                            if (tableModel.getRowCount() == 0)
+                                return;
+                            FileListEntry fl = tableModel.getEntry(0);
+                            (new ExternalFileMenuItem(frame, entry, "", fl.getLink(), null, panel.metaData(), fl.getType())).
+                                    actionPerformed(null);
+                        }
+                        break;
+                    case URL_COL:
+                        openExternalLink("url", e);
+                        break;
+                    case PDF_COL:
+                        openExternalLink("pdf", e);
+                        break;
+                    case PS_COL:
+                        openExternalLink("ps", e);
+                        break;
+                }
+            }
         }
 
         public void mouseEntered(MouseEvent e) {
@@ -741,10 +831,81 @@ public class ImportInspectionDialog extends JDialog {
 
         }
 
+        /**
+         * Show right-click menu. If the click happened in an icon column that presents its own popup menu,
+         * show that. Otherwise, show the ordinary popup menu.
+         * @param e The mouse event that triggered the popup.
+         */
+        public void showPopup(MouseEvent e) {
+            final int col = glTable.columnAtPoint(e.getPoint());
+            switch (col) {
+                case FILE_COL:
+                    showFileFieldMenu(e);
+                    break;
+                default:
+                    showOrdinaryRightClickMenu(e);
+                    break;
+            }
+
+        }
+
+        public void showOrdinaryRightClickMenu(MouseEvent e) {
+            popup.show(glTable, e.getX(), e.getY());
+        }
+
+        /**
+         * Show the popup menu for the FILE field.
+         * @param e The mouse event that triggered the popup.
+         */
+        public void showFileFieldMenu(MouseEvent e) {
+            final int row = glTable.rowAtPoint(e.getPoint());
+            BibtexEntry entry = (BibtexEntry)sortedList.get(row);
+            JPopupMenu menu = new JPopupMenu();
+            int count = 0;
+            Object o = entry.getField(GUIGlobals.FILE_FIELD);
+            FileListTableModel fileList = new FileListTableModel();
+            fileList.setContent((String)o);
+            // If there are one or more links, open the first one:
+            for (int i=0; i<fileList.getRowCount(); i++) {
+                FileListEntry flEntry = fileList.getEntry(i);
+                String description = flEntry.getDescription();
+                if ((description == null) || (description.trim().length() == 0))
+                    description = flEntry.getLink();
+                menu.add(new ExternalFileMenuItem(panel.frame(), entry, description,
+                        flEntry.getLink(), flEntry.getType().getIcon(), panel.metaData(),
+                        flEntry.getType()));
+                count++;
+            }
+            if (count == 0) {
+                showOrdinaryRightClickMenu(e);
+            }
+            else
+                menu.show(glTable, e.getX(), e.getY());
+        }
+
+        /**
+         * Open old-style external links after user clicks icon.
+         * @param fieldName The name of the BibTeX field this icon is used for.
+         * @param e The MouseEvent that triggered this operation.
+         */
+        public void openExternalLink(String fieldName, MouseEvent e) {
+            final int row = glTable.rowAtPoint(e.getPoint());
+            BibtexEntry entry = (BibtexEntry)sortedList.get(row);
+
+            Object link = entry.getField(fieldName);
+            try {
+                if (link != null)
+                    Util.openExternalViewer(panel.metaData(), (String) link, fieldName);
+            } catch (IOException ex) {
+                ex.printStackTrace();
+            }
+        }
+
+
         public void mouseReleased(MouseEvent e) {
             // Check if the user has right-clicked. If so, open the right-click menu.
             if (e.isPopupTrigger()) {
-                popup.show(glTable, e.getX(), e.getY());
+                showPopup(e);
                 return;
             }
         }
@@ -752,7 +913,7 @@ public class ImportInspectionDialog extends JDialog {
         public void mousePressed(MouseEvent e) {
             // Check if the user has right-clicked. If so, open the right-click menu.
             if (e.isPopupTrigger()) {
-                popup.show(glTable, e.getX(), e.getY());
+                showPopup(e);
                 return;
             }
 
@@ -835,6 +996,138 @@ public class ImportInspectionDialog extends JDialog {
         }
     }
 
+    class DownloadFile extends JMenuItem implements ActionListener,
+        DownloadExternalFile.DownloadCallback {
+
+        BibtexEntry entry = null;
+
+        public DownloadFile() {
+            super(Globals.lang("Download file"));
+            addActionListener(this);
+        }
+
+        public void actionPerformed(ActionEvent actionEvent) {
+            if (selectionModel.getSelected().size() != 1)
+                return;
+            entry = (BibtexEntry) selectionModel.getSelected().get(0);
+            String bibtexKey = entry.getCiteKey();
+            if (bibtexKey == null) {
+                int answer = JOptionPane.showConfirmDialog(frame,
+                        Globals.lang("This entry has no BibTeX key. Generate key now?"),
+                        Globals.lang("Download file"), JOptionPane.OK_CANCEL_OPTION,
+                        JOptionPane.QUESTION_MESSAGE);
+                if (answer == JOptionPane.OK_OPTION) {
+                    generateKeySelectedEntry();
+                    bibtexKey = entry.getCiteKey();
+                }
+            }
+            DownloadExternalFile def = new DownloadExternalFile(frame, metaData, bibtexKey);
+            try {
+                def.download(this);
+            } catch (IOException ex) {
+                ex.printStackTrace();
+            }
+        }
+
+        public void downloadComplete(FileListEntry file) {
+            ImportInspectionDialog.this.toFront(); // Hack
+            FileListTableModel model = new FileListTableModel();
+            String oldVal = (String)entry.getField(GUIGlobals.FILE_FIELD);
+            if (oldVal != null)
+                model.setContent(oldVal);
+            model.addEntry(model.getRowCount(), file);
+            entries.getReadWriteLock().writeLock().lock();
+            entry.setField(GUIGlobals.FILE_FIELD, model.getStringRepresentation());
+            entries.getReadWriteLock().writeLock().unlock();
+            glTable.repaint();
+        }
+    }
+
+    class AutoSetLinks extends JMenuItem implements ActionListener {
+
+        public AutoSetLinks() {
+            super(Globals.lang("Autoset external links"));
+            addActionListener(this);
+        }
+
+        public void actionPerformed(ActionEvent actionEvent) {
+            if (selectionModel.getSelected().size() != 1)
+                return;
+            final BibtexEntry entry = (BibtexEntry) selectionModel.getSelected().get(0);
+            String bibtexKey = entry.getCiteKey();
+            if (bibtexKey == null) {
+                int answer = JOptionPane.showConfirmDialog(frame,
+                        Globals.lang("This entry has no BibTeX key. Generate key now?"),
+                        Globals.lang("Download file"), JOptionPane.OK_CANCEL_OPTION,
+                        JOptionPane.QUESTION_MESSAGE);
+                if (answer == JOptionPane.OK_OPTION) {
+                    generateKeySelectedEntry();
+                    bibtexKey = entry.getCiteKey();
+                } else return; // Can't go on without the bibtex key.
+            }
+            final FileListTableModel model = new FileListTableModel();
+            String oldVal = (String)entry.getField(GUIGlobals.FILE_FIELD);
+            if (oldVal != null)
+                model.setContent(oldVal);
+            // We have a static utility method for searching for all relevant links:
+            JDialog diag = new JDialog(ImportInspectionDialog.this, true);
+            FileListEditor.autoSetLinks(entry, model, metaData, new ActionListener() {
+                public void actionPerformed(ActionEvent e) {
+                    if (e.getID() > 0) {
+                        entries.getReadWriteLock().writeLock().lock();
+                        entry.setField(GUIGlobals.FILE_FIELD, model.getStringRepresentation());
+                        entries.getReadWriteLock().writeLock().unlock();
+                        glTable.repaint();
+                    }
+                }
+            }, diag);
+
+        }
+    }
+
+    class LinkLocalFile extends JMenuItem implements ActionListener,
+        DownloadExternalFile.DownloadCallback {
+
+        BibtexEntry entry = null;
+
+        public LinkLocalFile() {
+            super(Globals.lang("Link local file"));
+            addActionListener(this);
+        }
+
+        public void actionPerformed(ActionEvent actionEvent) {
+            if (selectionModel.getSelected().size() != 1)
+                return;
+            entry = (BibtexEntry) selectionModel.getSelected().get(0);
+            FileListEntry flEntry = new FileListEntry("", "", null);
+            FileListEntryEditor editor = new FileListEntryEditor(frame, flEntry, false, true, metaData);
+            editor.setVisible(true);                                                 
+            if (editor.okPressed()) {
+                FileListTableModel model = new FileListTableModel();
+                String oldVal = (String)entry.getField(GUIGlobals.FILE_FIELD);
+                if (oldVal != null)
+                    model.setContent(oldVal);
+                model.addEntry(model.getRowCount(), flEntry);
+                entries.getReadWriteLock().writeLock().lock();
+                entry.setField(GUIGlobals.FILE_FIELD, model.getStringRepresentation());
+                entries.getReadWriteLock().writeLock().unlock();
+                glTable.repaint();
+            }
+        }
+
+        public void downloadComplete(FileListEntry file) {
+            ImportInspectionDialog.this.toFront(); // Hack
+            FileListTableModel model = new FileListTableModel();
+            String oldVal = (String)entry.getField(GUIGlobals.FILE_FIELD);
+            if (oldVal != null)
+                model.setContent(oldVal);
+            model.addEntry(model.getRowCount(), file);
+            entries.getReadWriteLock().writeLock().lock();
+            entry.setField(GUIGlobals.FILE_FIELD, model.getStringRepresentation());
+            entries.getReadWriteLock().writeLock().unlock();
+            glTable.repaint();
+        }
+    }
 
     class AttachFile extends JMenuItem implements ActionListener {
         String fileType;
@@ -893,7 +1186,9 @@ public class ImportInspectionDialog extends JDialog {
         for (int i = 2; i < PAD; i++) {
             comparators = comparatorChooser.getComparatorsForColumn(i);
             comparators.clear();
-            if (i == PDF_COL)
+            if (i == FILE_COL)
+                comparators.add(new IconComparator(new String[] {GUIGlobals.FILE_FIELD}));
+            else if (i == PDF_COL)
                 comparators.add(new IconComparator(new String[] {"pdf"}));
             else if (i == PS_COL)
                 comparators.add(new IconComparator(new String[] {"ps"}));
@@ -923,7 +1218,7 @@ public class ImportInspectionDialog extends JDialog {
     }
 
     class EntryTable extends JTable {
-        GeneralRenderer renderer = new GeneralRenderer(Color.white, true);
+        GeneralRenderer renderer = new GeneralRenderer(Color.white);
         public EntryTable(TableModel model) {
             super(model);
         }
@@ -978,6 +1273,14 @@ public class ImportInspectionDialog extends JDialog {
                 Object o;
                 switch (i) {
                     case DUPL_COL: return entry.isGroupHit() ?  duplLabel : null;
+                    case FILE_COL:
+                        o = entry.getField(GUIGlobals.FILE_FIELD);
+                        if (o != null) {
+                            FileListTableModel model = new FileListTableModel();
+                            model.setContent((String)o);
+                            fileLabel.setToolTipText(model.getToolTipHTMLRepresentation());
+                            return fileLabel;
+                        } else return null;
                     case PDF_COL:
                         o = entry.getField("pdf");
                         if (o != null) {
