@@ -15,6 +15,8 @@ import net.sf.jabref.Util;
 import ca.odell.glazedlists.gui.TableFormat;
 import ca.odell.glazedlists.matchers.Matcher;
 
+import javax.swing.*;
+
 /**
  * Created by IntelliJ IDEA.
  * User: alver
@@ -29,7 +31,8 @@ public class MainTableFormat implements TableFormat {
     ,
     URL_ = {"url", "doi"}
     ,
-    CITESEER = {"citeseerurl"};
+    CITESEER = {"citeseerurl"},
+    FILE = {GUIGlobals.FILE_FIELD};
 
     BasePanel panel;
 
@@ -108,7 +111,10 @@ public class MainTableFormat implements TableFormat {
                 return null;
 
             // Ok, so we are going to display an icon. Find out which one, and return it:
-            o = GUIGlobals.getTableIcon(iconType[hasField]);
+            if (iconType[hasField].equals(GUIGlobals.FILE_FIELD)) {
+                o = FileListTableModel.getFirstLabel((String)be.getField(GUIGlobals.FILE_FIELD));
+            } else
+                o = GUIGlobals.getTableIcon(iconType[hasField]);
         } else if (columns[col - padleft].equals(GUIGlobals.TYPE_HEADER)) {
             o = be.getType().getName();
         } else {
@@ -159,6 +165,8 @@ public class MainTableFormat implements TableFormat {
         // We add those that are enabled in preferences.
         iconCols.clear();
         int coln = 1;
+        if (Globals.prefs.getBoolean("fileColumn"))
+            iconCols.put(new Integer(coln++), FILE);
         if (Globals.prefs.getBoolean("pdfColumn"))
             iconCols.put(new Integer(coln++), PDF);
         if (Globals.prefs.getBoolean("urlColumn"))
