@@ -14,11 +14,8 @@ import java.util.Comparator;
 import java.util.List;
 
 /**
- * Created by IntelliJ IDEA.
- * User: alver
- * Date: Oct 15, 2005
- * Time: 3:02:52 AM
- * To change this template use File | Settings | File Templates.
+ * List event, mouse, key and focus listener for the main table that makes up the
+ * most part of the BasePanel for a single bib database.
  */
 public class MainTableSelectionListener implements ListEventListener, MouseListener,
         KeyListener, FocusListener {
@@ -112,8 +109,27 @@ public class MainTableSelectionListener implements ListEventListener, MouseListe
     }
 
     private void updatePreview(final BibtexEntry toShow, final boolean changedPreview) {
-        if (workingOnPreview)
+        updatePreview(toShow, changedPreview, 0);
+    }
+
+    private void updatePreview(final BibtexEntry toShow, final boolean changedPreview, int repeats) {
+        if (workingOnPreview) {
+            if (repeats > 0)
+                return; // We've already waited once. Give up on this selection.
+            Timer t = new Timer(50, new ActionListener() {
+                public void actionPerformed(ActionEvent actionEvent) {
+                    updatePreview(toShow, changedPreview, 1);
+                }
+            });
+            t.setRepeats(false);
+            t.start();
             return;
+        }
+        EventList list = table.getSelected();
+        // Check if the entry to preview is still selected:
+        if ((list.size() != 1) || ((BibtexEntry)list.get(0) != toShow)) {
+            return;
+        }
         final int mode = panel.getMode();
         workingOnPreview = true;
         final Runnable update = new Runnable() {
@@ -155,16 +171,21 @@ public class MainTableSelectionListener implements ListEventListener, MouseListe
         // First find the column on which the user has clicked.
         final int col = table.columnAtPoint(e.getPoint()),
                 row = table.rowAtPoint(e.getPoint());
+
         // Check if the user has right-clicked. If so, open the right-click menu.
         if (e.isPopupTrigger()) {
-            processPopupTrigger(e, row);
-            return;
+            // Check if the user has clicked on an icon cell to open url or pdf.
+            final String[] iconType = table.getIconTypeForColumn(col);
+            
+            if (iconType == null)
+                processPopupTrigger(e, row);
+            else
+                showIconRightClickMenu(e, row, iconType);
         }
     }
 
      public void mousePressed(MouseEvent e) {
-
-
+         
         // First find the column on which the user has clicked.
         final int col = table.columnAtPoint(e.getPoint()),
                 row = table.rowAtPoint(e.getPoint());
@@ -189,6 +210,12 @@ public class MainTableSelectionListener implements ListEventListener, MouseListe
             return;
         }
 
+         // Workaround for Windows. Right-click is not popup trigger on mousePressed, but
+         // on mouseReleased. Therefore we need to avoid taking action at this point, because
+         // action will be taken when the button is released:
+        if (Globals.ON_WIN && (iconType != null) && (e.getButton() != MouseEvent.BUTTON1))
+            return;
+
 
         if (iconType != null) {
 
@@ -218,7 +245,26 @@ public class MainTableSelectionListener implements ListEventListener, MouseListe
                     }
 
                     try {
-                        Util.openExternalViewer(panel.metaData(), (String)link, fieldName);
+                        // See if this is a simple file link field, or if it is a file-list
+                        // field that can specify a list of links:
+                        if (fieldName.equals(GUIGlobals.FILE_FIELD)) {
+
+                            // We use a FileListTableModel to parse the field content:
+                            FileListTableModel fileList = new FileListTableModel();
+                            fileList.setContent((String)link);
+                            // If there are one or more links, open the first one:
+                            if (fileList.getRowCount() > 0) {
+                                FileListEntry flEntry = fileList.getEntry(0);
+                                ExternalFileMenuItem item = new ExternalFileMenuItem
+                                        (panel.frame(), entry, "",
+                                        flEntry.getLink(), flEntry.getType().getIcon(),
+                                        panel.metaData(), flEntry.getType());
+                                item.actionPerformed(null);
+                            }
+                        } else {
+                            Util.openExternalViewer(panel.metaData(), (String)link, fieldName);
+                        }
+
                     }
                     catch (IOException ex) {
                         panel.output(Globals.lang("Error") + ": " + ex.getMessage());
@@ -260,14 +306,37 @@ public class MainTableSelectionListener implements ListEventListener, MouseListe
         BibtexEntry entry = (BibtexEntry) tableRows.get(row);
         JPopupMenu menu = new JPopupMenu();
         int count = 0;
-        for (int i=0; i<iconType.length; i++) {
-            Object o = entry.getField(iconType[i]);
-            if (o != null) {
-                menu.add(new ExternalFileMenuItem((String)o, (String)o,
-                        GUIGlobals.getTableIcon(iconType[i]).getIcon(),
-                        panel.metaData()));
+
+        // See if this is a simple file link field, or if it is a file-list
+        // field that can specify a list of links:
+        if (iconType[0].equals(GUIGlobals.FILE_FIELD)) {
+            // We use a FileListTableModel to parse the field content:
+            Object o = entry.getField(iconType[0]);
+            FileListTableModel fileList = new FileListTableModel();
+            fileList.setContent((String)o);
+            // If there are one or more links, open the first one:
+            for (int i=0; i<fileList.getRowCount(); i++) {
+                FileListEntry flEntry = fileList.getEntry(i);
+                String description = flEntry.getDescription();
+                if ((description == null) || (description.trim().length() == 0))
+                    description = flEntry.getLink();
+                menu.add(new ExternalFileMenuItem(panel.frame(), entry, description,
+                        flEntry.getLink(), flEntry.getType().getIcon(), panel.metaData(),
+                        flEntry.getType()));
                 count++;
             }
+
+        }
+        else {
+            for (int i=0; i<iconType.length; i++) {
+                Object o = entry.getField(iconType[i]);
+                if (o != null) {
+                    menu.add(new ExternalFileMenuItem(panel.frame(), entry, (String)o, (String)o,
+                            GUIGlobals.getTableIcon(iconType[i]).getIcon(),
+                            panel.metaData()));
+                    count++;
+                }
+            }
         }
         if (count == 0) {
             processPopupTrigger(e, row);
