@@ -24,38 +24,27 @@
  */
 package net.sf.jabref.imports;
 
-import net.sf.jabref.*;
-
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.Reader;
-
-import java.util.SortedSet;
-import java.util.TreeSet;
 import java.util.Iterator;
 import java.util.List;
+import java.util.SortedSet;
+import java.util.TreeSet;
 
-import java.util.regex.*;
+import net.sf.jabref.BibtexDatabase;
+import net.sf.jabref.BibtexEntry;
+import net.sf.jabref.Globals;
+import net.sf.jabref.KeyCollisionException;
+import net.sf.jabref.Util;
 
 
-/*
- * // int jabrefframe BibtexDatabase database=new BibtexDatabase(); String
- * filename=Globals.getNewFile(); ArrayList bibitems=readISI(filename); // is
- * there a getFileName(); Iterator it = bibitems.iterator();
- * while(it.hasNext()){ BibtexEntry entry = (BibtexEntry)it.next();
- * entry.setId(Util.createId(entry.getType(), database); try {
- * database.insertEntry(entry); } catch (KeyCollisionException ex) {
- *  } }
- */
 public class ImportFormatReader {
 
     public static String BIBTEX_FORMAT = "BibTeX";
-    private final static String SPACE_MARKER = "__SPC__";
-    private final static Pattern bracketsPattern = Pattern.compile("\\{.*\\}"),
-	spaceMarkerPattern = Pattern.compile(SPACE_MARKER);
 
   /** all import formats, in the defalt order of import formats */
   private SortedSet formats = new TreeSet();
@@ -85,6 +74,8 @@ public class ImportFormatReader {
     formats.add(new BiomailImporter());
     formats.add(new RepecNepImporter());  
     formats.add(new PdfXmpImporter());
+    formats.add(new CopacImporter());
+    formats.add(new MsBibImporter());
     
     // add all custom importers
     for (Iterator i = Globals.prefs.customImports.iterator(); i.hasNext(); ) {
@@ -197,7 +188,7 @@ public class ImportFormatReader {
    * 
    * <p>Elements are in default order.</p>
    * 
-   * @return all custom importers, elements are of type {@link InputFormat}
+   * @return all custom importers, elements are of type InputFormat
    */
   public SortedSet getCustomImportFormats() {
     SortedSet result = new TreeSet();
@@ -215,7 +206,7 @@ public class ImportFormatReader {
    * 
    * <p>Elements are in default order.</p>
    * 
-   * @return all custom importers, elements are of type {@link InputFormat}
+   * @return all custom importers, elements are of type InputFormat
    */
   public SortedSet getBuiltInInputFormats() {
     SortedSet result = new TreeSet();
@@ -233,7 +224,7 @@ public class ImportFormatReader {
    * 
    * <p>Elements are in default order.</p>
    * 
-   * @return all custom importers, elements are of type {@link InputFormat}
+   * @return all custom importers, elements are of type InputFormat
    */
   public SortedSet getImportFormats() {
     return this.formats;
@@ -454,6 +445,11 @@ public class ImportFormatReader {
     String usedFormat = null;
     int bestResult = 0;
 
+      /**String lastImport = Globals.prefs.get("lastAutodetectedImport");
+      for (Iterator i = getImportFormats().iterator(); i.hasNext();) {
+			ImportFormat imFo = (ImportFormat) i.next();
+      **/    
+
     // Cycle through all importers:
 		for (Iterator i = getImportFormats().iterator(); i.hasNext();) {
 			ImportFormat imFo = (ImportFormat) i.next();
@@ -478,7 +474,7 @@ public class ImportFormatReader {
 			} catch (Exception e) {
 			}
 		}
-      System.out.println("Used format: "+usedFormat);
+      //System.out.println("Used format: "+usedFormat);
     // Finally, if all else fails, see if it is a BibTeX file:
     if (entryList == null) {
 	try {
@@ -487,7 +483,8 @@ public class ImportFormatReader {
 		|| (pr.getDatabase().getStringCount() > 0)) {
 		entryList = pr;
         pr.setFile(new File(filename));
-		usedFormat = BIBTEX_FORMAT;
+            
+        usedFormat = BIBTEX_FORMAT;
 	    }
 	} catch (Throwable ex) {
 	    //ex.printStackTrace();
