@@ -165,7 +165,9 @@ public class ImportMenuItem extends JMenuItem implements ActionListener {
                                         LabelPatternUtil.makeLabel(Globals.prefs.getKeyPattern(), toAddTo, entry);
                                         //System.out.println("gen:"+entry.getCiteKey());
                                     }
-                                    
+                                    // Let the autocompleters, if any, harvest words from the entry: 
+                                    Util.updateCompletersForEntry(panel.getAutoCompleters(), entry);
+
                                     ce.addEdit(new UndoableInsertEntry(toAddTo, entry, panel));
                                 }
                             } catch (KeyCollisionException e) {
@@ -255,7 +257,8 @@ public class ImportMenuItem extends JMenuItem implements ActionListener {
             if (o[1] instanceof List) {
                 List entries = (List) o[1];
                 anythingUseful = anythingUseful | (entries.size() > 0);
-                Util.setAutomaticFields(entries); // set timestamp and owner
+                Util.setAutomaticFields(entries, Globals.prefs.getBoolean("overwriteOwner"),
+                        Globals.prefs.getBoolean("overwriteTimeStamp")); // set timestamp and owner
                 for (Iterator j = entries.iterator(); j.hasNext();) {
                     BibtexEntry entry = (BibtexEntry) j.next();
                     try {
