@@ -1,6 +1,7 @@
 package net.sf.jabref.imports;
 
 import net.sf.jabref.*;
+import net.sf.jabref.external.FileLinksUpgradeWarning;
 
 import javax.swing.*;
 import java.io.*;
@@ -10,10 +11,23 @@ import java.util.*;
 // The action concerned with opening an existing database.
 
 public class OpenDatabaseAction extends MnemonicAwareAction {
-    boolean showDialog;
 
+    boolean showDialog;
     private JabRefFrame frame;
 
+    // List of actions that may need to be called after opening the file. Such as
+    // upgrade actions etc. that may depend on the JabRef version that wrote the file:
+    private static ArrayList<PostOpenAction> postOpenActions =
+            new ArrayList<PostOpenAction>();
+
+    static {
+        // Add the action for checking for new custom entry types loaded from
+        // the bib file:
+        postOpenActions.add(new CheckForNewEntryTypesAction());
+        // Add the action for the new external file handling system in version 2.3:
+        postOpenActions.add(new FileLinksUpgradeWarning());
+    }
+
     public OpenDatabaseAction(JabRefFrame frame, boolean showDialog) {
         super(GUIGlobals.getImage("open"));
         this.frame = frame;
@@ -50,6 +64,28 @@ public class OpenDatabaseAction extends MnemonicAwareAction {
             filesToOpen.add(new File(Util.checkName(e.getActionCommand())));
         }
 
+        BasePanel toRaise = null;
+        int initialCount = filesToOpen.size(), removed = 0;
+        
+        // Check if any of the files are already open:
+        for (Iterator iterator = filesToOpen.iterator(); iterator.hasNext();) {
+            File file = (File) iterator.next();
+            for (int i=0; i<frame.getTabbedPane().getTabCount(); i++) {
+                BasePanel bp = (BasePanel)frame.baseAt(i);
+                if ((bp.getFile() != null) && bp.getFile().equals(file)) {
+                    iterator.remove();
+                    removed++;
+                    // See if we removed the final one. If so, we must perhaps
+                    // raise the BasePanel in question:
+                    if (removed == initialCount) {
+                        toRaise = bp;
+                    }
+                    break;
+                }
+            }
+        }
+
+
         // Run the actual open in a thread to prevent the program
         // locking until the file is loaded.
         if (filesToOpen.size() > 0) {
@@ -58,11 +94,18 @@ public class OpenDatabaseAction extends MnemonicAwareAction {
                 public void run() {
                     for (Iterator i=theFiles.iterator(); i.hasNext();)
                         openIt((File)i.next(), true);
+
                 }
             }).start();
             for (Iterator i=theFiles.iterator(); i.hasNext();)
                 frame.getFileHistory().newFile(((File)i.next()).getPath());
         }
+        // If no files are remaining to open, this could mean that a file was
+        // already open. If so, we may have to raise the correct tab:
+        else if (toRaise != null) {
+            frame.output(Globals.lang("File '%0' is already open.", toRaise.getFile().getPath()));
+            frame.getTabbedPane().setSelectedComponent(toRaise);
+        }
     }
 
     class OpenItSwingHelper implements Runnable {
@@ -91,6 +134,7 @@ public class OpenDatabaseAction extends MnemonicAwareAction {
                 // Should this be done _after_ we know it was successfully opened?
                 String encoding = Globals.prefs.get("defaultEncoding");
                 ParserResult pr = loadDatabase(file, encoding);
+
                 if ((pr == null) || (pr == ParserResult.INVALID_FORMAT)) {
                     JOptionPane.showMessageDialog(null, Globals.lang("Error opening file" + " '" + fileName + "'"),
                             Globals.lang("Error"),
@@ -99,21 +143,41 @@ public class OpenDatabaseAction extends MnemonicAwareAction {
                     return;
                 }
 
-                addNewDatabase(pr, file, raisePanel);
+                BasePanel panel = addNewDatabase(pr, file, raisePanel);
+
+                // After adding the database, go through our list and see if
+                // any post open actions need to be done. For instance, checking
+                // if we found new entry types that can be imported, or checking
+                // if the database contents should be modified due to new features
+                // in this version of JabRef:
+                performPostOpenActions(panel, pr, true);
 
             } catch (Exception ex) {
                 //ex.printStackTrace();
                 Util.showQuickErrorDialog(frame, Globals.lang("Open database"), ex);
-                /*
-                JOptionPane.showMessageDialog
-                        (frame, ex.getMessage(),
-                                Globals.lang("Open database"), JOptionPane.ERROR_MESSAGE);
-                                */
             }
         }
     }
 
-    public void addNewDatabase(ParserResult pr, File file,
+    /**
+     * Go through the list of post open actions, and perform those that need
+     * to be performed.
+     * @param panel The BasePanel where the database is shown.
+     * @param pr The result of the bib file parse operation.
+     */
+    public static void performPostOpenActions(BasePanel panel, ParserResult pr,
+                                              boolean mustRaisePanel) {
+        for (Iterator<PostOpenAction> iterator = postOpenActions.iterator(); iterator.hasNext();) {
+            PostOpenAction action = iterator.next();
+            if (action.isActionNecessary(pr)) {
+                if (mustRaisePanel)
+                    panel.frame().getTabbedPane().setSelectedComponent(panel);
+                action.performAction(panel, pr);
+            }
+        }
+    }
+
+    public BasePanel addNewDatabase(ParserResult pr, File file,
                                boolean raisePanel) {
 
         String fileName = file.getPath();
@@ -142,53 +206,15 @@ public class OpenDatabaseAction extends MnemonicAwareAction {
             }).start();
         }
         BasePanel bp = new BasePanel(frame, db, file, meta, pr.getEncoding());
-        /*
-         if (Globals.prefs.getBoolean("autoComplete")) {
-         db.setCompleters(autoCompleters);
-         }
-        */
 
         // file is set to null inside the EventDispatcherThread
         SwingUtilities.invokeLater(new OpenItSwingHelper(bp, file, raisePanel));
 
-        // See if any custom entry types were imported, but disregard those we already know:
-        for (Iterator i = pr.getEntryTypes().keySet().iterator(); i.hasNext();) {
-            String typeName = ((String) i.next()).toLowerCase();
-            if (BibtexEntryType.ALL_TYPES.get(typeName) != null)
-                i.remove();
-        }
-        if (pr.getEntryTypes().size() > 0) {
-
-
-            StringBuffer sb = new StringBuffer(Globals.lang("Custom entry types found in file") + ": ");
-            Object[] types = pr.getEntryTypes().keySet().toArray();
-            Arrays.sort(types);
-            for (int i = 0; i < types.length; i++) {
-                sb.append(types[i].toString()).append(", ");
-            }
-            String s = sb.toString();
-            int answer = JOptionPane.showConfirmDialog(frame,
-                    s.substring(0, s.length() - 2) + ".\n"
-                            + Globals.lang("Remember these entry types?"),
-                    Globals.lang("Custom entry types"),
-                    JOptionPane.YES_NO_OPTION,
-                    JOptionPane.QUESTION_MESSAGE);
-            if (answer == JOptionPane.YES_OPTION) {
-                // Import
-                HashMap et = pr.getEntryTypes();
-                for (Iterator i = et.keySet().iterator(); i.hasNext();) {
-                    BibtexEntryType typ = (BibtexEntryType) et.get(i.next());
-                    //System.out.println(":"+typ.getName()+"\n"+typ.toString());
-                    BibtexEntryType.ALL_TYPES.put(typ.getName().toLowerCase(), typ);
-                }
-
-            }
-        }
-
         frame.output(Globals.lang("Opened database") + " '" + fileName +
                 "' " + Globals.lang("with") + " " +
                 db.getEntryCount() + " " + Globals.lang("entries") + ".");
 
+        return bp;
     }
 
     public static ParserResult loadDatabase(File fileToOpen, String encoding)
@@ -246,17 +272,20 @@ public class OpenDatabaseAction extends MnemonicAwareAction {
         StringBuffer headerText = new StringBuffer();
         try {
             boolean keepon = true;
-            int piv = 0;
+            int piv = 0, offset = 0;
             int c;
 
             while (keepon) {
                 c = reader.read();
-                headerText.append((char) c);
-                if (((piv == 0) && Character.isWhitespace((char) c))
-                        || (c == GUIGlobals.SIGNATURE.charAt(piv)))
-                    piv++;
-                else //if (((char)c) == '@')
-                    keepon = false;
+                if ((piv == 0) && ((c == '%') || (Character.isWhitespace((char)c))))
+                    offset++;
+                else {
+                    headerText.append((char) c);
+                    if (c == GUIGlobals.SIGNATURE.charAt(piv))
+                        piv++;
+                    else //if (((char)c) == '@')
+                        keepon = false;
+                }
                 //System.out.println(headerText.toString());
                 found:
                 if (piv == GUIGlobals.SIGNATURE.length()) {
@@ -266,10 +295,15 @@ public class OpenDatabaseAction extends MnemonicAwareAction {
                     //    System.out.println("'"+headerText.toString().substring(0, headerText.length()-GUIGlobals.SIGNATURE.length())+"'");
                     // Found the signature. The rest of the line is unknown, so we skip
                     // it:
-                    while (reader.read() != '\n') ;
+                    while (reader.read() != '\n');
+                    // If the next line starts with something like "% ", handle this:
+                    while (((c =reader.read()) == '%') || (Character.isWhitespace((char)c)));
+                    // Then we must skip the "Encoding: ". We may already have read the first
+                    // character:
+                    if ((char)c != GUIGlobals.encPrefix.charAt(0))
+                        break found;
 
-                    // Then we must skip the "Encoding: "
-                    for (int i = 0; i < GUIGlobals.encPrefix.length(); i++) {
+                    for (int i = 1; i < GUIGlobals.encPrefix.length(); i++) {
                         if (reader.read() != GUIGlobals.encPrefix.charAt(i))
                             break found; // No,
                         // it
@@ -278,13 +312,16 @@ public class OpenDatabaseAction extends MnemonicAwareAction {
                         // to
                         // match.
                     }
-
+                    
                     // If ok, then read the rest of the line, which should contain the
                     // name
                     // of the encoding:
                     StringBuffer sb = new StringBuffer();
 
-                    while ((c = reader.read()) != '\n') sb.append((char) c);
+                    while ((c = reader.read()) != '\n') {
+                        sb.append((char) c);
+                    }
+
 
                     suppliedEncoding = sb.toString();
                 }
