@@ -177,6 +177,10 @@ public class LabelPatternUtil {
                   else if (val.equals("authors")) {
                     _sbvalue.append(allAuthors(authString));
                   }
+                  // Last author's last name
+                  else if (val.equals("authorLast")) {
+                     _sbvalue.append(lastAuthor(authString));
+                  }
                   else if (val.equals("authorIni")) {
                     _sbvalue.append(oneAuthorPlusIni(authString));
                   }
@@ -184,9 +188,13 @@ public class LabelPatternUtil {
                     int num = Integer.parseInt(val.substring(7));
                                         _sbvalue.append(authIniN(authString,num));
                   }
-                                  else if (val.equals("auth.auth.ea")) {
+                  else if (val.equals("auth.auth.ea")) {
                     _sbvalue.append(authAuthEa(authString));
                   }
+                  else if (val.equals("auth.etal")) {
+                    _sbvalue.append(authEtal(authString));
+                  }
+
                   else if (val.equals("authshort")) {
                     _sbvalue.append(authshort(authString));
                   }
@@ -247,6 +255,10 @@ public class LabelPatternUtil {
                       num = fa.length();
                     _sbvalue.append(fa.substring(0,num));
                   }
+                  // Last editor's last name
+                  else if (val.equals("editorLast")) {
+                      _sbvalue.append(lastAuthor((String)(_entry.getField("editor"))));
+                  }
                   else {
                     // This "ed" business was a dead end, so just use it literally:
                     _sbvalue.append(_entry.getField(val).toString());
@@ -255,6 +267,7 @@ public class LabelPatternUtil {
                 else if (val.equals("firstpage")) {
                   _sbvalue.append(firstPage(_entry.getField("pages").toString()));
                 }
+
                 else if (val.equals("lastpage")) {
                   _sbvalue.append(lastPage(_entry.getField("pages").toString()));
                 }
@@ -278,6 +291,16 @@ public class LabelPatternUtil {
                   _sbvalue.append(getTitleWords(1, _entry));
                 }
 
+               else if (val.matches("keyword\\d+")) {
+                    int num = Integer.parseInt(val.substring(7));
+                    String kw = _entry.getField("keywords").toString();
+                    if (kw != null) {
+                        String[] keywords = kw.split("[,;]\\s*");
+                        if ((num > 0) && (num < keywords.length))
+                            _sbvalue.append(keywords[num-1].trim());
+                    }
+               }
+
                 // we havent seen any special demands
                 else {
                   _sbvalue.append(_entry.getField(val).toString());
@@ -298,8 +321,8 @@ public class LabelPatternUtil {
                 // Abbreviate - that is,
                 //System.out.println(_sbvalue.toString());
                 StringBuffer abbr = new StringBuffer();
-                String[] words = _sbvalue.toString().replaceAll("[\\{\\}]","")
-                        .split("[ \r\n]");//split("\\b");
+                String[] words = _sbvalue.toString().replaceAll("[\\{\\}']","")
+                        .split("[ \r\n\"]");//split("\\b");
                 for (int word=0; word<words.length; word++)
                     if (words[word].length() > 0)
                         abbr.append(words[word].charAt(0));
@@ -504,18 +527,31 @@ public class LabelPatternUtil {
    * @return the sur name of an author/editor
    */
   private static String firstAuthor(String authorField) {
-    String author = "";
-    // This code was part of 'ApplyRule' in 'ArticleLabelRule'
-    //String[] tokens = ImportFormatReader.fixAuthor_lastNameFirst(authorField).split("\\band\\b");
-      String[] tokens = AuthorList.fixAuthorForAlphabetization(authorField).split("\\band\\b");
+    String[] tokens = AuthorList.fixAuthorForAlphabetization(authorField).split("\\band\\b");
     if (tokens.length > 0) { // if author is empty
       String[] firstAuthor = tokens[0].replaceAll("\\s+", " ").split(" ");
-      author += firstAuthor[0];
+      return firstAuthor[0];
 
     }
-    return author;
+    else return "";
   }
 
+    /**
+       * Gets the last name of the last author/editor
+       * @param authorField a <code>String</code>
+       * @return the sur name of an author/editor
+       */
+      private static String lastAuthor(String authorField) {
+        String[] tokens = AuthorList.fixAuthorForAlphabetization(authorField).split("\\band\\b");
+        if (tokens.length > 0) { // if author is empty
+          String[] lastAuthor = tokens[tokens.length-1].replaceAll("\\s+", " ").trim().split(" ");
+          return lastAuthor[0];
+
+        }
+        else return "";
+      }
+
+
   /**
    * Gets the last name of all authors/editors
    * @param authorField a <code>String</code>
@@ -613,6 +649,31 @@ public class LabelPatternUtil {
     return author.toString();
   }
 
+  /**
+   * auth.etal format:
+   * Isaac Newton and James Maxwell and Albert Einstein (1960)
+   * Isaac Newton and James Maxwell (1960)
+   *  give:
+   * Newton.etal
+   * Newton.Maxwell
+   */
+  private static String authEtal(String authorField) {
+    authorField = AuthorList.fixAuthorForAlphabetization(authorField);
+    StringBuffer author = new StringBuffer();
+
+    String[] tokens = authorField.split("\\band\\b");
+    if (tokens.length == 0) {
+      return "";
+    }
+    author.append((tokens[0].split(","))[0]);
+    if (tokens.length == 2)
+        author.append(".").append((tokens[1].split(","))[0]);
+    else if (tokens.length > 2)
+      author.append(".etal");
+
+    return author.toString();
+  }
+
   /**
    * The first N characters of the Mth author/editor.
    */
