@@ -178,13 +178,14 @@ public class IntegrityCheck
 //        back.add("bad end (" +fieldName +" field)");
         failed = true ;
       }
-      if (structure.indexOf("NN,NN") > -1)
+      /*if (structure.indexOf("NN,NN") > -1)
       {
         messages.add( new IntegrityMessage( IntegrityMessage.NAME_SEMANTIC_WARNING,
                                             entry, fieldName, null))  ;
+
 //        back.add("something could be wrong in " +fieldName +" field") ;
         failed = true ;
-      }
+      } */
 
 //      if (failed)
 //        System.out.println(authors +" #" +structure.toString() +"#") ;
